# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
    from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
    from datadog_api_client.v1.model.synthetics_browser_variable import SyntheticsBrowserVariable


class SyntheticsBrowserTestConfig(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_assertion import SyntheticsAssertion
        from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
        from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
        from datadog_api_client.v1.model.synthetics_browser_variable import SyntheticsBrowserVariable

        return {
            "assertions": ([SyntheticsAssertion],),
            "config_variables": ([SyntheticsConfigVariable],),
            "request": (SyntheticsTestRequest,),
            "set_cookie": (str,),
            "variables": ([SyntheticsBrowserVariable],),
        }

    attribute_map = {
        "assertions": "assertions",
        "config_variables": "configVariables",
        "request": "request",
        "set_cookie": "setCookie",
        "variables": "variables",
    }

    def __init__(
        self_,
        request: SyntheticsTestRequest,
        config_variables: Union[List[SyntheticsConfigVariable], UnsetType] = unset,
        set_cookie: Union[str, UnsetType] = unset,
        variables: Union[List[SyntheticsBrowserVariable], UnsetType] = unset,
        **kwargs,
    ):
        """
        Configuration object for a Synthetic browser test.

        :param assertions: Array of assertions used for the test.
        :type assertions: [SyntheticsAssertion]

        :param config_variables: Array of variables used for the test.
        :type config_variables: [SyntheticsConfigVariable], optional

        :param request: Object describing the Synthetic test request.
        :type request: SyntheticsTestRequest

        :param set_cookie: Cookies to be used for the request, using the `Set-Cookie <https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie>`_ syntax.
        :type set_cookie: str, optional

        :param variables: Array of variables used for the test steps.
        :type variables: [SyntheticsBrowserVariable], optional
        """
        if config_variables is not unset:
            kwargs["config_variables"] = config_variables
        if set_cookie is not unset:
            kwargs["set_cookie"] = set_cookie
        if variables is not unset:
            kwargs["variables"] = variables
        super().__init__(kwargs)
        assertions = kwargs.get("assertions", [])

        self_.assertions = assertions
        self_.request = request



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.usage_top_avg_metrics_pagination import UsageTopAvgMetricsPagination


class UsageTopAvgMetricsMetadata(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.usage_top_avg_metrics_pagination import UsageTopAvgMetricsPagination

        return {
            "day": (datetime,),
            "month": (datetime,),
            "pagination": (UsageTopAvgMetricsPagination,),
        }

    attribute_map = {
        "day": "day",
        "month": "month",
        "pagination": "pagination",
    }

    def __init__(
        self_,
        day: Union[datetime, UnsetType] = unset,
        month: Union[datetime, UnsetType] = unset,
        pagination: Union[UsageTopAvgMetricsPagination, UnsetType] = unset,
        **kwargs,
    ):
        """
        The object containing document metadata.

        :param day: The day value from the user request that contains the returned usage data. (If day was used the request)
        :type day: datetime, optional

        :param month: The month value from the user request that contains the returned usage data. (If month was used the request)
        :type month: datetime, optional

        :param pagination: The metadata for the current pagination.
        :type pagination: UsageTopAvgMetricsPagination, optional
        """
        if day is not unset:
            kwargs["day"] = day
        if month is not unset:
            kwargs["month"] = month
        if pagination is not unset:
            kwargs["pagination"] = pagination
        super().__init__(kwargs)



"""
Update Confluent account returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.confluent_cloud_api import ConfluentCloudApi
from datadog_api_client.v2.model.confluent_account_type import ConfluentAccountType
from datadog_api_client.v2.model.confluent_account_update_request import ConfluentAccountUpdateRequest
from datadog_api_client.v2.model.confluent_account_update_request_attributes import (
    ConfluentAccountUpdateRequestAttributes,
)
from datadog_api_client.v2.model.confluent_account_update_request_data import ConfluentAccountUpdateRequestData

# there is a valid "confluent_account" in the system
CONFLUENT_ACCOUNT_DATA_ATTRIBUTES_API_KEY = environ["CONFLUENT_ACCOUNT_DATA_ATTRIBUTES_API_KEY"]
CONFLUENT_ACCOUNT_DATA_ID = environ["CONFLUENT_ACCOUNT_DATA_ID"]

body = ConfluentAccountUpdateRequest(
    data=ConfluentAccountUpdateRequestData(
        attributes=ConfluentAccountUpdateRequestAttributes(
            api_key=CONFLUENT_ACCOUNT_DATA_ATTRIBUTES_API_KEY,
            api_secret="update-secret",
            tags=[
                "updated_tag:val",
            ],
        ),
        type=ConfluentAccountType.CONFLUENT_CLOUD_ACCOUNTS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ConfluentCloudApi(api_client)
    response = api_instance.update_confluent_account(account_id=CONFLUENT_ACCOUNT_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.creator import Creator
    from datadog_api_client.v1.model.monitor_options import MonitorOptions
    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
    from datadog_api_client.v1.model.monitor_state import MonitorState
    from datadog_api_client.v1.model.monitor_type import MonitorType


class MonitorUpdateRequest(ModelNormal):
    validations = {
        "priority": {
            "inclusive_maximum": 5,
            "inclusive_minimum": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.creator import Creator
        from datadog_api_client.v1.model.monitor_options import MonitorOptions
        from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
        from datadog_api_client.v1.model.monitor_state import MonitorState
        from datadog_api_client.v1.model.monitor_type import MonitorType

        return {
            "created": (datetime,),
            "creator": (Creator,),
            "deleted": (datetime, none_type),
            "id": (int,),
            "message": (str,),
            "modified": (datetime,),
            "multi": (bool,),
            "name": (str,),
            "options": (MonitorOptions,),
            "overall_state": (MonitorOverallStates,),
            "priority": (int,),
            "query": (str,),
            "restricted_roles": ([str],),
            "state": (MonitorState,),
            "tags": ([str],),
            "type": (MonitorType,),
        }

    attribute_map = {
        "created": "created",
        "creator": "creator",
        "deleted": "deleted",
        "id": "id",
        "message": "message",
        "modified": "modified",
        "multi": "multi",
        "name": "name",
        "options": "options",
        "overall_state": "overall_state",
        "priority": "priority",
        "query": "query",
        "restricted_roles": "restricted_roles",
        "state": "state",
        "tags": "tags",
        "type": "type",
    }
    read_only_vars = {
        "created",
        "creator",
        "deleted",
        "id",
        "modified",
        "multi",
        "overall_state",
        "state",
    }

    def __init__(
        self_,
        created: Union[datetime, UnsetType] = unset,
        creator: Union[Creator, UnsetType] = unset,
        deleted: Union[datetime, none_type, UnsetType] = unset,
        id: Union[int, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        modified: Union[datetime, UnsetType] = unset,
        multi: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        options: Union[MonitorOptions, UnsetType] = unset,
        overall_state: Union[MonitorOverallStates, UnsetType] = unset,
        priority: Union[int, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        restricted_roles: Union[List[str], UnsetType] = unset,
        state: Union[MonitorState, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        type: Union[MonitorType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object describing a monitor update request.

        :param created: Timestamp of the monitor creation.
        :type created: datetime, optional

        :param creator: Object describing the creator of the shared element.
        :type creator: Creator, optional

        :param deleted: Whether or not the monitor is deleted. (Always ``null`` )
        :type deleted: datetime, none_type, optional

        :param id: ID of this monitor.
        :type id: int, optional

        :param message: A message to include with notifications for this monitor.
        :type message: str, optional

        :param modified: Last timestamp when the monitor was edited.
        :type modified: datetime, optional

        :param multi: Whether or not the monitor is broken down on different groups.
        :type multi: bool, optional

        :param name: The monitor name.
        :type name: str, optional

        :param options: List of options associated with your monitor.
        :type options: MonitorOptions, optional

        :param overall_state: The different states your monitor can be in.
        :type overall_state: MonitorOverallStates, optional

        :param priority: Integer from 1 (high) to 5 (low) indicating alert severity.
        :type priority: int, optional

        :param query: The monitor query.
        :type query: str, optional

        :param restricted_roles: A list of unique role identifiers to define which roles are allowed to edit the monitor. The unique identifiers for all roles can be pulled from the `Roles API <https://docs.datadoghq.com/api/latest/roles/#list-roles>`_ and are located in the ``data.id`` field. Editing a monitor includes any updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. ``restricted_roles`` is the successor of ``locked``. For more information about ``locked`` and ``restricted_roles`` , see the `monitor options docs <https://docs.datadoghq.com/monitors/guide/monitor_api_options/#permissions-options>`_.
        :type restricted_roles: [str], optional

        :param state: Wrapper object with the different monitor states.
        :type state: MonitorState, optional

        :param tags: Tags associated to your monitor.
        :type tags: [str], optional

        :param type: The type of the monitor. For more information about ``type`` , see the `monitor options <https://docs.datadoghq.com/monitors/guide/monitor_api_options/>`_ docs.
        :type type: MonitorType, optional
        """
        if created is not unset:
            kwargs["created"] = created
        if creator is not unset:
            kwargs["creator"] = creator
        if deleted is not unset:
            kwargs["deleted"] = deleted
        if id is not unset:
            kwargs["id"] = id
        if message is not unset:
            kwargs["message"] = message
        if modified is not unset:
            kwargs["modified"] = modified
        if multi is not unset:
            kwargs["multi"] = multi
        if name is not unset:
            kwargs["name"] = name
        if options is not unset:
            kwargs["options"] = options
        if overall_state is not unset:
            kwargs["overall_state"] = overall_state
        if priority is not unset:
            kwargs["priority"] = priority
        if query is not unset:
            kwargs["query"] = query
        if restricted_roles is not unset:
            kwargs["restricted_roles"] = restricted_roles
        if state is not unset:
            kwargs["state"] = state
        if tags is not unset:
            kwargs["tags"] = tags
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



"""
Update a GCP integration returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.gcp_integration_api import GCPIntegrationApi
from datadog_api_client.v1.model.gcp_account import GCPAccount

body = GCPAccount(
    auth_provider_x509_cert_url="https://www.googleapis.com/oauth2/v1/certs",
    auth_uri="https://accounts.google.com/o/oauth2/auth",
    client_email="api-dev@datadog-sandbox.iam.gserviceaccount.com",
    client_id="123456712345671234567",
    client_x509_cert_url="https://www.googleapis.com/robot/v1/metadata/x509/$CLIENT_EMAIL",
    errors=[
        "*",
    ],
    host_filters="key:value,filter:example",
    private_key="private_key",
    private_key_id="123456789abcdefghi123456789abcdefghijklm",
    project_id="datadog-apitest",
    token_uri="https://accounts.google.com/o/oauth2/token",
    type="service_account",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = GCPIntegrationApi(api_client)
    response = api_instance.update_gcp_integration(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.confluent_resource_response_attributes import ConfluentResourceResponseAttributes


class ConfluentAccountResponseAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.confluent_resource_response_attributes import (
            ConfluentResourceResponseAttributes,
        )

        return {
            "api_key": (str,),
            "resources": ([ConfluentResourceResponseAttributes],),
            "tags": ([str],),
        }

    attribute_map = {
        "api_key": "api_key",
        "resources": "resources",
        "tags": "tags",
    }

    def __init__(
        self_,
        api_key: str,
        resources: Union[List[ConfluentResourceResponseAttributes], UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        The attributes of a Confluent account.

        :param api_key: The API key associated with your Confluent account.
        :type api_key: str

        :param resources: A list of Confluent resources associated with the Confluent account.
        :type resources: [ConfluentResourceResponseAttributes], optional

        :param tags: A list of strings representing tags. Can be a single key, or key-value pairs separated by a colon.
        :type tags: [str], optional
        """
        if resources is not unset:
            kwargs["resources"] = resources
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)

        self_.api_key = api_key



"""
Search metrics returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.metrics_api import MetricsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.list_metrics(
        q="q",
    )

    print(response)



"""
List all AuthN Mappings returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.authn_mappings_api import AuthNMappingsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AuthNMappingsApi(api_client)
    response = api_instance.list_authn_mappings()

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class AddSignalToIncidentRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "add_to_signal_timeline": (bool,),
            "incident_id": (int,),
            "version": (int,),
        }

    attribute_map = {
        "add_to_signal_timeline": "add_to_signal_timeline",
        "incident_id": "incident_id",
        "version": "version",
    }

    def __init__(
        self_,
        incident_id: int,
        add_to_signal_timeline: Union[bool, UnsetType] = unset,
        version: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes describing which incident to add the signal to.

        :param add_to_signal_timeline: Whether to post the signal on the incident timeline.
        :type add_to_signal_timeline: bool, optional

        :param incident_id: Public ID attribute of the incident to which the signal will be added.
        :type incident_id: int

        :param version: Version of the updated signal. If server side version is higher, update will be rejected.
        :type version: int, optional
        """
        if add_to_signal_timeline is not unset:
            kwargs["add_to_signal_timeline"] = add_to_signal_timeline
        if version is not unset:
            kwargs["version"] = version
        super().__init__(kwargs)

        self_.incident_id = incident_id



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class UsageAttributionSort(ModelSimple):
    """
    The field to sort by.

    :param value: If omitted defaults to "custom_timeseries_usage". Must be one of ["api_percentage", "snmp_usage", "apm_host_usage", "api_usage", "appsec_usage", "appsec_percentage", "container_usage", "custom_timeseries_percentage", "container_percentage", "apm_host_percentage", "npm_host_percentage", "browser_percentage", "browser_usage", "infra_host_percentage", "snmp_percentage", "npm_host_usage", "infra_host_usage", "custom_timeseries_usage", "lambda_functions_usage", "lambda_functions_percentage", "lambda_invocations_usage", "lambda_invocations_percentage", "estimated_indexed_logs_usage", "estimated_indexed_logs_percentage", "estimated_ingested_logs_usage", "estimated_ingested_logs_percentage", "estimated_indexed_spans_usage", "estimated_indexed_spans_percentage", "estimated_ingested_spans_usage", "estimated_ingested_spans_percentage", "apm_fargate_usage", "apm_fargate_percentage", "appsec_fargate_usage", "appsec_fargate_percentage", "estimated_rum_usage_attribution_usage", "estimated_rum_usage_attribution_percentage"].
    :type value: str
    """

    allowed_values = {
        "api_percentage",
        "snmp_usage",
        "apm_host_usage",
        "api_usage",
        "appsec_usage",
        "appsec_percentage",
        "container_usage",
        "custom_timeseries_percentage",
        "container_percentage",
        "apm_host_percentage",
        "npm_host_percentage",
        "browser_percentage",
        "browser_usage",
        "infra_host_percentage",
        "snmp_percentage",
        "npm_host_usage",
        "infra_host_usage",
        "custom_timeseries_usage",
        "lambda_functions_usage",
        "lambda_functions_percentage",
        "lambda_invocations_usage",
        "lambda_invocations_percentage",
        "estimated_indexed_logs_usage",
        "estimated_indexed_logs_percentage",
        "estimated_ingested_logs_usage",
        "estimated_ingested_logs_percentage",
        "estimated_indexed_spans_usage",
        "estimated_indexed_spans_percentage",
        "estimated_ingested_spans_usage",
        "estimated_ingested_spans_percentage",
        "apm_fargate_usage",
        "apm_fargate_percentage",
        "appsec_fargate_usage",
        "appsec_fargate_percentage",
        "estimated_rum_usage_attribution_usage",
        "estimated_rum_usage_attribution_percentage",
    }
    API_PERCENTAGE: ClassVar["UsageAttributionSort"]
    SNMP_USAGE: ClassVar["UsageAttributionSort"]
    APM_HOST_USAGE: ClassVar["UsageAttributionSort"]
    API_USAGE: ClassVar["UsageAttributionSort"]
    APPSEC_USAGE: ClassVar["UsageAttributionSort"]
    APPSEC_PERCENTAGE: ClassVar["UsageAttributionSort"]
    CONTAINER_USAGE: ClassVar["UsageAttributionSort"]
    CUSTOM_TIMESERIES_PERCENTAGE: ClassVar["UsageAttributionSort"]
    CONTAINER_PERCENTAGE: ClassVar["UsageAttributionSort"]
    APM_HOST_PERCENTAGE: ClassVar["UsageAttributionSort"]
    NPM_HOST_PERCENTAGE: ClassVar["UsageAttributionSort"]
    BROWSER_PERCENTAGE: ClassVar["UsageAttributionSort"]
    BROWSER_USAGE: ClassVar["UsageAttributionSort"]
    INFRA_HOST_PERCENTAGE: ClassVar["UsageAttributionSort"]
    SNMP_PERCENTAGE: ClassVar["UsageAttributionSort"]
    NPM_HOST_USAGE: ClassVar["UsageAttributionSort"]
    INFRA_HOST_USAGE: ClassVar["UsageAttributionSort"]
    CUSTOM_TIMESERIES_USAGE: ClassVar["UsageAttributionSort"]
    LAMBDA_FUNCTIONS_USAGE: ClassVar["UsageAttributionSort"]
    LAMBDA_FUNCTIONS_PERCENTAGE: ClassVar["UsageAttributionSort"]
    LAMBDA_INVOCATIONS_USAGE: ClassVar["UsageAttributionSort"]
    LAMBDA_INVOCATIONS_PERCENTAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INDEXED_LOGS_USAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INDEXED_LOGS_PERCENTAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INGESTED_LOGS_USAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INGESTED_LOGS_PERCENTAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INDEXED_SPANS_USAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INDEXED_SPANS_PERCENTAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INGESTED_SPANS_USAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_INGESTED_SPANS_PERCENTAGE: ClassVar["UsageAttributionSort"]
    APM_FARGATE_USAGE: ClassVar["UsageAttributionSort"]
    APM_FARGATE_PERCENTAGE: ClassVar["UsageAttributionSort"]
    APPSEC_FARGATE_USAGE: ClassVar["UsageAttributionSort"]
    APPSEC_FARGATE_PERCENTAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_RUM_USAGE_ATTRIBUTION_USAGE: ClassVar["UsageAttributionSort"]
    ESTIMATED_RUM_USAGE_ATTRIBUTION_PERCENTAGE: ClassVar["UsageAttributionSort"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


UsageAttributionSort.API_PERCENTAGE = UsageAttributionSort("api_percentage")
UsageAttributionSort.SNMP_USAGE = UsageAttributionSort("snmp_usage")
UsageAttributionSort.APM_HOST_USAGE = UsageAttributionSort("apm_host_usage")
UsageAttributionSort.API_USAGE = UsageAttributionSort("api_usage")
UsageAttributionSort.APPSEC_USAGE = UsageAttributionSort("appsec_usage")
UsageAttributionSort.APPSEC_PERCENTAGE = UsageAttributionSort("appsec_percentage")
UsageAttributionSort.CONTAINER_USAGE = UsageAttributionSort("container_usage")
UsageAttributionSort.CUSTOM_TIMESERIES_PERCENTAGE = UsageAttributionSort("custom_timeseries_percentage")
UsageAttributionSort.CONTAINER_PERCENTAGE = UsageAttributionSort("container_percentage")
UsageAttributionSort.APM_HOST_PERCENTAGE = UsageAttributionSort("apm_host_percentage")
UsageAttributionSort.NPM_HOST_PERCENTAGE = UsageAttributionSort("npm_host_percentage")
UsageAttributionSort.BROWSER_PERCENTAGE = UsageAttributionSort("browser_percentage")
UsageAttributionSort.BROWSER_USAGE = UsageAttributionSort("browser_usage")
UsageAttributionSort.INFRA_HOST_PERCENTAGE = UsageAttributionSort("infra_host_percentage")
UsageAttributionSort.SNMP_PERCENTAGE = UsageAttributionSort("snmp_percentage")
UsageAttributionSort.NPM_HOST_USAGE = UsageAttributionSort("npm_host_usage")
UsageAttributionSort.INFRA_HOST_USAGE = UsageAttributionSort("infra_host_usage")
UsageAttributionSort.CUSTOM_TIMESERIES_USAGE = UsageAttributionSort("custom_timeseries_usage")
UsageAttributionSort.LAMBDA_FUNCTIONS_USAGE = UsageAttributionSort("lambda_functions_usage")
UsageAttributionSort.LAMBDA_FUNCTIONS_PERCENTAGE = UsageAttributionSort("lambda_functions_percentage")
UsageAttributionSort.LAMBDA_INVOCATIONS_USAGE = UsageAttributionSort("lambda_invocations_usage")
UsageAttributionSort.LAMBDA_INVOCATIONS_PERCENTAGE = UsageAttributionSort("lambda_invocations_percentage")
UsageAttributionSort.ESTIMATED_INDEXED_LOGS_USAGE = UsageAttributionSort("estimated_indexed_logs_usage")
UsageAttributionSort.ESTIMATED_INDEXED_LOGS_PERCENTAGE = UsageAttributionSort("estimated_indexed_logs_percentage")
UsageAttributionSort.ESTIMATED_INGESTED_LOGS_USAGE = UsageAttributionSort("estimated_ingested_logs_usage")
UsageAttributionSort.ESTIMATED_INGESTED_LOGS_PERCENTAGE = UsageAttributionSort("estimated_ingested_logs_percentage")
UsageAttributionSort.ESTIMATED_INDEXED_SPANS_USAGE = UsageAttributionSort("estimated_indexed_spans_usage")
UsageAttributionSort.ESTIMATED_INDEXED_SPANS_PERCENTAGE = UsageAttributionSort("estimated_indexed_spans_percentage")
UsageAttributionSort.ESTIMATED_INGESTED_SPANS_USAGE = UsageAttributionSort("estimated_ingested_spans_usage")
UsageAttributionSort.ESTIMATED_INGESTED_SPANS_PERCENTAGE = UsageAttributionSort("estimated_ingested_spans_percentage")
UsageAttributionSort.APM_FARGATE_USAGE = UsageAttributionSort("apm_fargate_usage")
UsageAttributionSort.APM_FARGATE_PERCENTAGE = UsageAttributionSort("apm_fargate_percentage")
UsageAttributionSort.APPSEC_FARGATE_USAGE = UsageAttributionSort("appsec_fargate_usage")
UsageAttributionSort.APPSEC_FARGATE_PERCENTAGE = UsageAttributionSort("appsec_fargate_percentage")
UsageAttributionSort.ESTIMATED_RUM_USAGE_ATTRIBUTION_USAGE = UsageAttributionSort(
    "estimated_rum_usage_attribution_usage"
)
UsageAttributionSort.ESTIMATED_RUM_USAGE_ATTRIBUTION_PERCENTAGE = UsageAttributionSort(
    "estimated_rum_usage_attribution_percentage"
)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class WidgetCustomLink(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "is_hidden": (bool,),
            "label": (str,),
            "link": (str,),
            "override_label": (str,),
        }

    attribute_map = {
        "is_hidden": "is_hidden",
        "label": "label",
        "link": "link",
        "override_label": "override_label",
    }

    def __init__(
        self_,
        is_hidden: Union[bool, UnsetType] = unset,
        label: Union[str, UnsetType] = unset,
        link: Union[str, UnsetType] = unset,
        override_label: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Custom links help you connect a data value to a URL, like a Datadog page or your AWS console.

        :param is_hidden: The flag for toggling context menu link visibility.
        :type is_hidden: bool, optional

        :param label: The label for the custom link URL. Keep the label short and descriptive. Use metrics and tags as variables.
        :type label: str, optional

        :param link: The URL of the custom link. URL must include ``http`` or ``https``. A relative URL must start with ``/``.
        :type link: str, optional

        :param override_label: The label ID that refers to a context menu link. Can be ``logs`` , ``hosts`` , ``traces`` , ``profiles`` , ``processes`` , ``containers`` , or ``rum``.
        :type override_label: str, optional
        """
        if is_hidden is not unset:
            kwargs["is_hidden"] = is_hidden
        if label is not unset:
            kwargs["label"] = label
        if link is not unset:
            kwargs["link"] = link
        if override_label is not unset:
            kwargs["override_label"] = override_label
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class MonitorThresholdWindowOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "recovery_window": (str, none_type),
            "trigger_window": (str, none_type),
        }

    attribute_map = {
        "recovery_window": "recovery_window",
        "trigger_window": "trigger_window",
    }

    def __init__(
        self_,
        recovery_window: Union[str, none_type, UnsetType] = unset,
        trigger_window: Union[str, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        Alerting time window options.

        :param recovery_window: Describes how long an anomalous metric must be normal before the alert recovers.
        :type recovery_window: str, none_type, optional

        :param trigger_window: Describes how long a metric must be anomalous before an alert triggers.
        :type trigger_window: str, none_type, optional
        """
        if recovery_window is not unset:
            kwargs["recovery_window"] = recovery_window
        if trigger_window is not unset:
            kwargs["trigger_window"] = trigger_window
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.sunburst_widget_legend_inline_automatic_type import (
        SunburstWidgetLegendInlineAutomaticType,
    )


class SunburstWidgetLegendInlineAutomatic(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.sunburst_widget_legend_inline_automatic_type import (
            SunburstWidgetLegendInlineAutomaticType,
        )

        return {
            "hide_percent": (bool,),
            "hide_value": (bool,),
            "type": (SunburstWidgetLegendInlineAutomaticType,),
        }

    attribute_map = {
        "hide_percent": "hide_percent",
        "hide_value": "hide_value",
        "type": "type",
    }

    def __init__(
        self_,
        type: SunburstWidgetLegendInlineAutomaticType,
        hide_percent: Union[bool, UnsetType] = unset,
        hide_value: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Configuration of inline or automatic legends.

        :param hide_percent: Whether to hide the percentages of the groups.
        :type hide_percent: bool, optional

        :param hide_value: Whether to hide the values of the groups.
        :type hide_value: bool, optional

        :param type: Whether to show the legend inline or let it be automatically generated.
        :type type: SunburstWidgetLegendInlineAutomaticType
        """
        if hide_percent is not unset:
            kwargs["hide_percent"] = hide_percent
        if hide_value is not unset:
            kwargs["hide_value"] = hide_value
        super().__init__(kwargs)

        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.notebooks_response_data import NotebooksResponseData
    from datadog_api_client.v1.model.notebooks_response_meta import NotebooksResponseMeta


class NotebooksResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.notebooks_response_data import NotebooksResponseData
        from datadog_api_client.v1.model.notebooks_response_meta import NotebooksResponseMeta

        return {
            "data": ([NotebooksResponseData],),
            "meta": (NotebooksResponseMeta,),
        }

    attribute_map = {
        "data": "data",
        "meta": "meta",
    }

    def __init__(
        self_,
        data: Union[List[NotebooksResponseData], UnsetType] = unset,
        meta: Union[NotebooksResponseMeta, UnsetType] = unset,
        **kwargs,
    ):
        """
        Notebooks get all response.

        :param data: List of notebook definitions.
        :type data: [NotebooksResponseData], optional

        :param meta: Searches metadata returned by the API.
        :type meta: NotebooksResponseMeta, optional
        """
        if data is not unset:
            kwargs["data"] = data
        if meta is not unset:
            kwargs["meta"] = meta
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class GeomapWidgetDefinitionStyle(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "palette": (str,),
            "palette_flip": (bool,),
        }

    attribute_map = {
        "palette": "palette",
        "palette_flip": "palette_flip",
    }

    def __init__(self_, palette: str, palette_flip: bool, **kwargs):
        """
        The style to apply to the widget.

        :param palette: The color palette to apply to the widget.
        :type palette: str

        :param palette_flip: Whether to flip the palette tones.
        :type palette_flip: bool
        """
        super().__init__(kwargs)

        self_.palette = palette
        self_.palette_flip = palette_flip



"""
Delete an existing incident service returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incident_services_api import IncidentServicesApi

# there is a valid "service" in the system
SERVICE_DATA_ID = environ["SERVICE_DATA_ID"]

configuration = Configuration()
configuration.unstable_operations["delete_incident_service"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentServicesApi(api_client)
    api_instance.delete_incident_service(
        service_id=SERVICE_DATA_ID,
    )



"""
Create an Application key with scopes for current user returns "Created" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.key_management_api import KeyManagementApi
from datadog_api_client.v2.model.application_key_create_attributes import ApplicationKeyCreateAttributes
from datadog_api_client.v2.model.application_key_create_data import ApplicationKeyCreateData
from datadog_api_client.v2.model.application_key_create_request import ApplicationKeyCreateRequest
from datadog_api_client.v2.model.application_keys_type import ApplicationKeysType

body = ApplicationKeyCreateRequest(
    data=ApplicationKeyCreateData(
        type=ApplicationKeysType.APPLICATION_KEYS,
        attributes=ApplicationKeyCreateAttributes(
            name="Example-Create_an_Application_key_with_scopes_for_current_user_returns_Created_response",
            scopes=[
                "dashboards_read",
                "dashboards_write",
                "dashboards_public_share",
            ],
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = KeyManagementApi(api_client)
    response = api_instance.create_current_user_application_key(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_definition import WidgetDefinition
    from datadog_api_client.v1.model.widget_layout import WidgetLayout
    from datadog_api_client.v1.model.alert_graph_widget_definition import AlertGraphWidgetDefinition
    from datadog_api_client.v1.model.alert_value_widget_definition import AlertValueWidgetDefinition
    from datadog_api_client.v1.model.change_widget_definition import ChangeWidgetDefinition
    from datadog_api_client.v1.model.check_status_widget_definition import CheckStatusWidgetDefinition
    from datadog_api_client.v1.model.distribution_widget_definition import DistributionWidgetDefinition
    from datadog_api_client.v1.model.event_stream_widget_definition import EventStreamWidgetDefinition
    from datadog_api_client.v1.model.event_timeline_widget_definition import EventTimelineWidgetDefinition
    from datadog_api_client.v1.model.free_text_widget_definition import FreeTextWidgetDefinition
    from datadog_api_client.v1.model.geomap_widget_definition import GeomapWidgetDefinition
    from datadog_api_client.v1.model.group_widget_definition import GroupWidgetDefinition
    from datadog_api_client.v1.model.heat_map_widget_definition import HeatMapWidgetDefinition
    from datadog_api_client.v1.model.host_map_widget_definition import HostMapWidgetDefinition
    from datadog_api_client.v1.model.i_frame_widget_definition import IFrameWidgetDefinition
    from datadog_api_client.v1.model.image_widget_definition import ImageWidgetDefinition
    from datadog_api_client.v1.model.log_stream_widget_definition import LogStreamWidgetDefinition
    from datadog_api_client.v1.model.monitor_summary_widget_definition import MonitorSummaryWidgetDefinition
    from datadog_api_client.v1.model.note_widget_definition import NoteWidgetDefinition
    from datadog_api_client.v1.model.query_value_widget_definition import QueryValueWidgetDefinition
    from datadog_api_client.v1.model.scatter_plot_widget_definition import ScatterPlotWidgetDefinition
    from datadog_api_client.v1.model.slo_widget_definition import SLOWidgetDefinition
    from datadog_api_client.v1.model.slo_list_widget_definition import SLOListWidgetDefinition
    from datadog_api_client.v1.model.service_map_widget_definition import ServiceMapWidgetDefinition
    from datadog_api_client.v1.model.service_summary_widget_definition import ServiceSummaryWidgetDefinition
    from datadog_api_client.v1.model.sunburst_widget_definition import SunburstWidgetDefinition
    from datadog_api_client.v1.model.table_widget_definition import TableWidgetDefinition
    from datadog_api_client.v1.model.timeseries_widget_definition import TimeseriesWidgetDefinition
    from datadog_api_client.v1.model.toplist_widget_definition import ToplistWidgetDefinition
    from datadog_api_client.v1.model.tree_map_widget_definition import TreeMapWidgetDefinition
    from datadog_api_client.v1.model.list_stream_widget_definition import ListStreamWidgetDefinition
    from datadog_api_client.v1.model.funnel_widget_definition import FunnelWidgetDefinition
    from datadog_api_client.v1.model.topology_map_widget_definition import TopologyMapWidgetDefinition


class Widget(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_definition import WidgetDefinition
        from datadog_api_client.v1.model.widget_layout import WidgetLayout

        return {
            "definition": (WidgetDefinition,),
            "id": (int,),
            "layout": (WidgetLayout,),
        }

    attribute_map = {
        "definition": "definition",
        "id": "id",
        "layout": "layout",
    }

    def __init__(
        self_,
        definition: Union[
            WidgetDefinition,
            AlertGraphWidgetDefinition,
            AlertValueWidgetDefinition,
            ChangeWidgetDefinition,
            CheckStatusWidgetDefinition,
            DistributionWidgetDefinition,
            EventStreamWidgetDefinition,
            EventTimelineWidgetDefinition,
            FreeTextWidgetDefinition,
            GeomapWidgetDefinition,
            GroupWidgetDefinition,
            HeatMapWidgetDefinition,
            HostMapWidgetDefinition,
            IFrameWidgetDefinition,
            ImageWidgetDefinition,
            LogStreamWidgetDefinition,
            MonitorSummaryWidgetDefinition,
            NoteWidgetDefinition,
            QueryValueWidgetDefinition,
            ScatterPlotWidgetDefinition,
            SLOWidgetDefinition,
            SLOListWidgetDefinition,
            ServiceMapWidgetDefinition,
            ServiceSummaryWidgetDefinition,
            SunburstWidgetDefinition,
            TableWidgetDefinition,
            TimeseriesWidgetDefinition,
            ToplistWidgetDefinition,
            TreeMapWidgetDefinition,
            ListStreamWidgetDefinition,
            FunnelWidgetDefinition,
            TopologyMapWidgetDefinition,
        ],
        id: Union[int, UnsetType] = unset,
        layout: Union[WidgetLayout, UnsetType] = unset,
        **kwargs,
    ):
        """
        Information about widget.

        **Note** : The ``layout`` property is required for widgets in dashboards with ``free`` ``layout_type``.
              For the **new dashboard layout** , the ``layout`` property depends on the ``reflow_type`` of the dashboard.

        .. code-block::

             - If `reflow_type` is `fixed`, `layout` is required.
             - If `reflow_type` is `auto`, `layout` should not be set.

        :param definition: `Definition of the widget <https://docs.datadoghq.com/dashboards/widgets/>`_.
        :type definition: WidgetDefinition

        :param id: ID of the widget.
        :type id: int, optional

        :param layout: The layout for a widget on a ``free`` or **new dashboard layout** dashboard.
        :type layout: WidgetLayout, optional
        """
        if id is not unset:
            kwargs["id"] = id
        if layout is not unset:
            kwargs["layout"] = layout
        super().__init__(kwargs)

        self_.definition = definition



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.formula_limit import FormulaLimit


class QueryFormula(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.formula_limit import FormulaLimit

        return {
            "formula": (str,),
            "limit": (FormulaLimit,),
        }

    attribute_map = {
        "formula": "formula",
        "limit": "limit",
    }

    def __init__(self_, formula: str, limit: Union[FormulaLimit, UnsetType] = unset, **kwargs):
        """
        A formula for calculation based on one or more queries.

        :param formula: Formula string, referencing one or more queries with their name property.
        :type formula: str

        :param limit: Message for specifying limits to the number of values returned by a query.
        :type limit: FormulaLimit, optional
        """
        if limit is not unset:
            kwargs["limit"] = limit
        super().__init__(kwargs)

        self_.formula = formula



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsTestRequestBodyType(ModelSimple):
    """
    Type of the request body.

    :param value: Must be one of ["text/plain", "application/json", "text/xml", "text/html", "application/x-www-form-urlencoded", "graphql"].
    :type value: str
    """

    allowed_values = {
        "text/plain",
        "application/json",
        "text/xml",
        "text/html",
        "application/x-www-form-urlencoded",
        "graphql",
    }
    TEXT_PLAIN: ClassVar["SyntheticsTestRequestBodyType"]
    APPLICATION_JSON: ClassVar["SyntheticsTestRequestBodyType"]
    TEXT_XML: ClassVar["SyntheticsTestRequestBodyType"]
    TEXT_HTML: ClassVar["SyntheticsTestRequestBodyType"]
    APPLICATION_X_WWW_FORM_URLENCODED: ClassVar["SyntheticsTestRequestBodyType"]
    GRAPHQL: ClassVar["SyntheticsTestRequestBodyType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsTestRequestBodyType.TEXT_PLAIN = SyntheticsTestRequestBodyType("text/plain")
SyntheticsTestRequestBodyType.APPLICATION_JSON = SyntheticsTestRequestBodyType("application/json")
SyntheticsTestRequestBodyType.TEXT_XML = SyntheticsTestRequestBodyType("text/xml")
SyntheticsTestRequestBodyType.TEXT_HTML = SyntheticsTestRequestBodyType("text/html")
SyntheticsTestRequestBodyType.APPLICATION_X_WWW_FORM_URLENCODED = SyntheticsTestRequestBodyType(
    "application/x-www-form-urlencoded"
)
SyntheticsTestRequestBodyType.GRAPHQL = SyntheticsTestRequestBodyType("graphql")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MonitorType(ModelSimple):
    """
    The type of the monitor. For more information about `type`, see the [monitor options](https://docs.datadoghq.com/monitors/guide/monitor_api_options/) docs.

    :param value: Must be one of ["composite", "event alert", "log alert", "metric alert", "process alert", "query alert", "rum alert", "service check", "synthetics alert", "trace-analytics alert", "slo alert", "event-v2 alert", "audit alert", "ci-pipelines alert", "ci-tests alert", "error-tracking alert"].
    :type value: str
    """

    allowed_values = {
        "composite",
        "event alert",
        "log alert",
        "metric alert",
        "process alert",
        "query alert",
        "rum alert",
        "service check",
        "synthetics alert",
        "trace-analytics alert",
        "slo alert",
        "event-v2 alert",
        "audit alert",
        "ci-pipelines alert",
        "ci-tests alert",
        "error-tracking alert",
    }
    COMPOSITE: ClassVar["MonitorType"]
    EVENT_ALERT: ClassVar["MonitorType"]
    LOG_ALERT: ClassVar["MonitorType"]
    METRIC_ALERT: ClassVar["MonitorType"]
    PROCESS_ALERT: ClassVar["MonitorType"]
    QUERY_ALERT: ClassVar["MonitorType"]
    RUM_ALERT: ClassVar["MonitorType"]
    SERVICE_CHECK: ClassVar["MonitorType"]
    SYNTHETICS_ALERT: ClassVar["MonitorType"]
    TRACE_ANALYTICS_ALERT: ClassVar["MonitorType"]
    SLO_ALERT: ClassVar["MonitorType"]
    EVENT_V2_ALERT: ClassVar["MonitorType"]
    AUDIT_ALERT: ClassVar["MonitorType"]
    CI_PIPELINES_ALERT: ClassVar["MonitorType"]
    CI_TESTS_ALERT: ClassVar["MonitorType"]
    ERROR_TRACKING_ALERT: ClassVar["MonitorType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MonitorType.COMPOSITE = MonitorType("composite")
MonitorType.EVENT_ALERT = MonitorType("event alert")
MonitorType.LOG_ALERT = MonitorType("log alert")
MonitorType.METRIC_ALERT = MonitorType("metric alert")
MonitorType.PROCESS_ALERT = MonitorType("process alert")
MonitorType.QUERY_ALERT = MonitorType("query alert")
MonitorType.RUM_ALERT = MonitorType("rum alert")
MonitorType.SERVICE_CHECK = MonitorType("service check")
MonitorType.SYNTHETICS_ALERT = MonitorType("synthetics alert")
MonitorType.TRACE_ANALYTICS_ALERT = MonitorType("trace-analytics alert")
MonitorType.SLO_ALERT = MonitorType("slo alert")
MonitorType.EVENT_V2_ALERT = MonitorType("event-v2 alert")
MonitorType.AUDIT_ALERT = MonitorType("audit alert")
MonitorType.CI_PIPELINES_ALERT = MonitorType("ci-pipelines alert")
MonitorType.CI_TESTS_ALERT = MonitorType("ci-tests alert")
MonitorType.ERROR_TRACKING_ALERT = MonitorType("error-tracking alert")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.list_application_keys_response import ListApplicationKeysResponse
from datadog_api_client.v2.model.application_keys_sort import ApplicationKeysSort
from datadog_api_client.v2.model.application_key_response import ApplicationKeyResponse
from datadog_api_client.v2.model.application_key_create_request import ApplicationKeyCreateRequest
from datadog_api_client.v2.model.partial_application_key_response import PartialApplicationKeyResponse
from datadog_api_client.v2.model.application_key_update_request import ApplicationKeyUpdateRequest


class ServiceAccountsApi:
    """
    Create, edit, and disable service accounts.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_service_account_application_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApplicationKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys",
                "operation_id": "create_service_account_application_key",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "service_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_account_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (ApplicationKeyCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_service_account_application_key_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}",
                "operation_id": "delete_service_account_application_key",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "service_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_account_id",
                    "location": "path",
                },
                "app_key_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "app_key_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_service_account_application_key_endpoint = _Endpoint(
            settings={
                "response_type": (PartialApplicationKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}",
                "operation_id": "get_service_account_application_key",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "service_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_account_id",
                    "location": "path",
                },
                "app_key_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "app_key_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_service_account_application_keys_endpoint = _Endpoint(
            settings={
                "response_type": (ListApplicationKeysResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys",
                "operation_id": "list_service_account_application_keys",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "service_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_account_id",
                    "location": "path",
                },
                "page_size": {
                    "openapi_types": (int,),
                    "attribute": "page[size]",
                    "location": "query",
                },
                "page_number": {
                    "openapi_types": (int,),
                    "attribute": "page[number]",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (ApplicationKeysSort,),
                    "attribute": "sort",
                    "location": "query",
                },
                "filter": {
                    "openapi_types": (str,),
                    "attribute": "filter",
                    "location": "query",
                },
                "filter_created_at_start": {
                    "openapi_types": (str,),
                    "attribute": "filter[created_at][start]",
                    "location": "query",
                },
                "filter_created_at_end": {
                    "openapi_types": (str,),
                    "attribute": "filter[created_at][end]",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_service_account_application_key_endpoint = _Endpoint(
            settings={
                "response_type": (PartialApplicationKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}",
                "operation_id": "update_service_account_application_key",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "service_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_account_id",
                    "location": "path",
                },
                "app_key_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "app_key_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (ApplicationKeyUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_service_account_application_key(
        self,
        service_account_id: str,
        body: ApplicationKeyCreateRequest,
    ) -> ApplicationKeyResponse:
        """Create an application key for this service account.

        Create an application key for this service account.

        :param service_account_id: The ID of the service account.
        :type service_account_id: str
        :type body: ApplicationKeyCreateRequest
        :rtype: ApplicationKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_account_id"] = service_account_id

        kwargs["body"] = body

        return self._create_service_account_application_key_endpoint.call_with_http_info(**kwargs)

    def delete_service_account_application_key(
        self,
        service_account_id: str,
        app_key_id: str,
    ) -> None:
        """Delete an application key for this service account.

        Delete an application key owned by this service account.

        :param service_account_id: The ID of the service account.
        :type service_account_id: str
        :param app_key_id: The ID of the application key.
        :type app_key_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_account_id"] = service_account_id

        kwargs["app_key_id"] = app_key_id

        return self._delete_service_account_application_key_endpoint.call_with_http_info(**kwargs)

    def get_service_account_application_key(
        self,
        service_account_id: str,
        app_key_id: str,
    ) -> PartialApplicationKeyResponse:
        """Get one application key for this service account.

        Get an application key owned by this service account.

        :param service_account_id: The ID of the service account.
        :type service_account_id: str
        :param app_key_id: The ID of the application key.
        :type app_key_id: str
        :rtype: PartialApplicationKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_account_id"] = service_account_id

        kwargs["app_key_id"] = app_key_id

        return self._get_service_account_application_key_endpoint.call_with_http_info(**kwargs)

    def list_service_account_application_keys(
        self,
        service_account_id: str,
        *,
        page_size: Union[int, UnsetType] = unset,
        page_number: Union[int, UnsetType] = unset,
        sort: Union[ApplicationKeysSort, UnsetType] = unset,
        filter: Union[str, UnsetType] = unset,
        filter_created_at_start: Union[str, UnsetType] = unset,
        filter_created_at_end: Union[str, UnsetType] = unset,
    ) -> ListApplicationKeysResponse:
        """List application keys for this service account.

        List all application keys available for this service account.

        :param service_account_id: The ID of the service account.
        :type service_account_id: str
        :param page_size: Size for a given page. The maximum allowed value is 5000.
        :type page_size: int, optional
        :param page_number: Specific page number to return.
        :type page_number: int, optional
        :param sort: Application key attribute used to sort results. Sort order is ascending
            by default. In order to specify a descending sort, prefix the
            attribute with a minus sign.
        :type sort: ApplicationKeysSort, optional
        :param filter: Filter application keys by the specified string.
        :type filter: str, optional
        :param filter_created_at_start: Only include application keys created on or after the specified date.
        :type filter_created_at_start: str, optional
        :param filter_created_at_end: Only include application keys created on or before the specified date.
        :type filter_created_at_end: str, optional
        :rtype: ListApplicationKeysResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_account_id"] = service_account_id

        if page_size is not unset:
            kwargs["page_size"] = page_size

        if page_number is not unset:
            kwargs["page_number"] = page_number

        if sort is not unset:
            kwargs["sort"] = sort

        if filter is not unset:
            kwargs["filter"] = filter

        if filter_created_at_start is not unset:
            kwargs["filter_created_at_start"] = filter_created_at_start

        if filter_created_at_end is not unset:
            kwargs["filter_created_at_end"] = filter_created_at_end

        return self._list_service_account_application_keys_endpoint.call_with_http_info(**kwargs)

    def update_service_account_application_key(
        self,
        service_account_id: str,
        app_key_id: str,
        body: ApplicationKeyUpdateRequest,
    ) -> PartialApplicationKeyResponse:
        """Edit an application key for this service account.

        Edit an application key owned by this service account.

        :param service_account_id: The ID of the service account.
        :type service_account_id: str
        :param app_key_id: The ID of the application key.
        :type app_key_id: str
        :type body: ApplicationKeyUpdateRequest
        :rtype: PartialApplicationKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_account_id"] = service_account_id

        kwargs["app_key_id"] = app_key_id

        kwargs["body"] = body

        return self._update_service_account_application_key_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class TreeMapGroupBy(ModelSimple):
    """
    (deprecated) The attribute formerly used to group elements in the widget.

    :param value: Must be one of ["user", "family", "process"].
    :type value: str
    """

    allowed_values = {
        "user",
        "family",
        "process",
    }
    USER: ClassVar["TreeMapGroupBy"]
    FAMILY: ClassVar["TreeMapGroupBy"]
    PROCESS: ClassVar["TreeMapGroupBy"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


TreeMapGroupBy.USER = TreeMapGroupBy("user")
TreeMapGroupBy.FAMILY = TreeMapGroupBy("family")
TreeMapGroupBy.PROCESS = TreeMapGroupBy("process")



"""
Add AWS Log Lambda ARN returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.aws_logs_integration_api import AWSLogsIntegrationApi
from datadog_api_client.v1.model.aws_account_and_lambda_request import AWSAccountAndLambdaRequest

body = AWSAccountAndLambdaRequest(
    account_id="1234567",
    lambda_arn="arn:aws:lambda:us-east-1:1234567:function:LogsCollectionAPITest",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AWSLogsIntegrationApi(api_client)
    response = api_instance.create_aws_lambda_arn(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.agent_check import AgentCheck
    from datadog_api_client.v1.model.host_meta_install_method import HostMetaInstallMethod


class HostMeta(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.agent_check import AgentCheck
        from datadog_api_client.v1.model.host_meta_install_method import HostMetaInstallMethod

        return {
            "agent_checks": ([AgentCheck],),
            "agent_version": (str,),
            "cpu_cores": (int,),
            "fbsd_v": ([str, none_type],),
            "gohai": (str,),
            "install_method": (HostMetaInstallMethod,),
            "mac_v": ([str, none_type],),
            "machine": (str,),
            "nix_v": ([str, none_type],),
            "platform": (str,),
            "processor": (str,),
            "python_v": (str,),
            "socket_fqdn": (str,),
            "socket_hostname": (str,),
            "win_v": ([str, none_type],),
        }

    attribute_map = {
        "agent_checks": "agent_checks",
        "agent_version": "agent_version",
        "cpu_cores": "cpuCores",
        "fbsd_v": "fbsdV",
        "gohai": "gohai",
        "install_method": "install_method",
        "mac_v": "macV",
        "machine": "machine",
        "nix_v": "nixV",
        "platform": "platform",
        "processor": "processor",
        "python_v": "pythonV",
        "socket_fqdn": "socket-fqdn",
        "socket_hostname": "socket-hostname",
        "win_v": "winV",
    }

    def __init__(
        self_,
        agent_checks: Union[List[AgentCheck], UnsetType] = unset,
        agent_version: Union[str, UnsetType] = unset,
        cpu_cores: Union[int, UnsetType] = unset,
        fbsd_v: Union[List[str], UnsetType] = unset,
        gohai: Union[str, UnsetType] = unset,
        install_method: Union[HostMetaInstallMethod, UnsetType] = unset,
        mac_v: Union[List[str], UnsetType] = unset,
        machine: Union[str, UnsetType] = unset,
        nix_v: Union[List[str], UnsetType] = unset,
        platform: Union[str, UnsetType] = unset,
        processor: Union[str, UnsetType] = unset,
        python_v: Union[str, UnsetType] = unset,
        socket_fqdn: Union[str, UnsetType] = unset,
        socket_hostname: Union[str, UnsetType] = unset,
        win_v: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Metadata associated with your host.

        :param agent_checks: A list of Agent checks running on the host.
        :type agent_checks: [AgentCheck], optional

        :param agent_version: The Datadog Agent version.
        :type agent_version: str, optional

        :param cpu_cores: The number of cores.
        :type cpu_cores: int, optional

        :param fbsd_v: An array of Mac versions.
        :type fbsd_v: [str, none_type], optional

        :param gohai: JSON string containing system information.
        :type gohai: str, optional

        :param install_method: Agent install method.
        :type install_method: HostMetaInstallMethod, optional

        :param mac_v: An array of Mac versions.
        :type mac_v: [str, none_type], optional

        :param machine: The machine architecture.
        :type machine: str, optional

        :param nix_v: Array of Unix versions.
        :type nix_v: [str, none_type], optional

        :param platform: The OS platform.
        :type platform: str, optional

        :param processor: The processor.
        :type processor: str, optional

        :param python_v: The Python version.
        :type python_v: str, optional

        :param socket_fqdn: The socket fqdn.
        :type socket_fqdn: str, optional

        :param socket_hostname: The socket hostname.
        :type socket_hostname: str, optional

        :param win_v: An array of Windows versions.
        :type win_v: [str, none_type], optional
        """
        if agent_checks is not unset:
            kwargs["agent_checks"] = agent_checks
        if agent_version is not unset:
            kwargs["agent_version"] = agent_version
        if cpu_cores is not unset:
            kwargs["cpu_cores"] = cpu_cores
        if fbsd_v is not unset:
            kwargs["fbsd_v"] = fbsd_v
        if gohai is not unset:
            kwargs["gohai"] = gohai
        if install_method is not unset:
            kwargs["install_method"] = install_method
        if mac_v is not unset:
            kwargs["mac_v"] = mac_v
        if machine is not unset:
            kwargs["machine"] = machine
        if nix_v is not unset:
            kwargs["nix_v"] = nix_v
        if platform is not unset:
            kwargs["platform"] = platform
        if processor is not unset:
            kwargs["processor"] = processor
        if python_v is not unset:
            kwargs["python_v"] = python_v
        if socket_fqdn is not unset:
            kwargs["socket_fqdn"] = socket_fqdn
        if socket_hostname is not unset:
            kwargs["socket_hostname"] = socket_hostname
        if win_v is not unset:
            kwargs["win_v"] = win_v
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class MetricMetadata(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "description": (str,),
            "integration": (str,),
            "per_unit": (str,),
            "short_name": (str,),
            "statsd_interval": (int,),
            "type": (str,),
            "unit": (str,),
        }

    attribute_map = {
        "description": "description",
        "integration": "integration",
        "per_unit": "per_unit",
        "short_name": "short_name",
        "statsd_interval": "statsd_interval",
        "type": "type",
        "unit": "unit",
    }
    read_only_vars = {
        "integration",
    }

    def __init__(
        self_,
        description: Union[str, UnsetType] = unset,
        integration: Union[str, UnsetType] = unset,
        per_unit: Union[str, UnsetType] = unset,
        short_name: Union[str, UnsetType] = unset,
        statsd_interval: Union[int, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        unit: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object with all metric related metadata.

        :param description: Metric description.
        :type description: str, optional

        :param integration: Name of the integration that sent the metric if applicable.
        :type integration: str, optional

        :param per_unit: Per unit of the metric such as ``second`` in ``bytes per second``.
        :type per_unit: str, optional

        :param short_name: A more human-readable and abbreviated version of the metric name.
        :type short_name: str, optional

        :param statsd_interval: StatsD flush interval of the metric in seconds if applicable.
        :type statsd_interval: int, optional

        :param type: Metric type such as ``gauge`` or ``rate``.
        :type type: str, optional

        :param unit: Primary unit of the metric such as ``byte`` or ``operation``.
        :type unit: str, optional
        """
        if description is not unset:
            kwargs["description"] = description
        if integration is not unset:
            kwargs["integration"] = integration
        if per_unit is not unset:
            kwargs["per_unit"] = per_unit
        if short_name is not unset:
            kwargs["short_name"] = short_name
        if statsd_interval is not unset:
            kwargs["statsd_interval"] = statsd_interval
        if type is not unset:
            kwargs["type"] = type
        if unit is not unset:
            kwargs["unit"] = unit
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    file_type,
)
from datadog_api_client.v1.model.organization_list_response import OrganizationListResponse
from datadog_api_client.v1.model.organization_create_response import OrganizationCreateResponse
from datadog_api_client.v1.model.organization_create_body import OrganizationCreateBody
from datadog_api_client.v1.model.organization_response import OrganizationResponse
from datadog_api_client.v1.model.organization import Organization
from datadog_api_client.v1.model.org_downgraded_response import OrgDowngradedResponse
from datadog_api_client.v1.model.idp_response import IdpResponse


class OrganizationsApi:
    """
    Create, edit, and manage your organizations. Read more about `multi-org accounts <https://docs.datadoghq.com/account_management/multi_organization>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_child_org_endpoint = _Endpoint(
            settings={
                "response_type": (OrganizationCreateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/org",
                "operation_id": "create_child_org",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (OrganizationCreateBody,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._downgrade_org_endpoint = _Endpoint(
            settings={
                "response_type": (OrgDowngradedResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/org/{public_id}/downgrade",
                "operation_id": "downgrade_org",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_org_endpoint = _Endpoint(
            settings={
                "response_type": (OrganizationResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/org/{public_id}",
                "operation_id": "get_org",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_orgs_endpoint = _Endpoint(
            settings={
                "response_type": (OrganizationListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/org",
                "operation_id": "list_orgs",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_org_endpoint = _Endpoint(
            settings={
                "response_type": (OrganizationResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/org/{public_id}",
                "operation_id": "update_org",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (Organization,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._upload_idp_for_org_endpoint = _Endpoint(
            settings={
                "response_type": (IdpResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/org/{public_id}/idp_metadata",
                "operation_id": "upload_idp_for_org",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "idp_file": {
                    "required": True,
                    "openapi_types": (file_type,),
                    "attribute": "idp_file",
                    "location": "form",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["multipart/form-data"]},
            api_client=api_client,
        )

    def create_child_org(
        self,
        body: OrganizationCreateBody,
    ) -> OrganizationCreateResponse:
        """Create a child organization.

        Create a child organization.

        This endpoint requires the
        `multi-organization account <https://docs.datadoghq.com/account_management/multi_organization/>`_
        feature and must be enabled by
        `contacting support <https://docs.datadoghq.com/help/>`_.

        Once a new child organization is created, you can interact with it
        by using the ``org.public_id`` , ``api_key.key`` , and
        ``application_key.hash`` provided in the response.

        :param body: Organization object that needs to be created
        :type body: OrganizationCreateBody
        :rtype: OrganizationCreateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_child_org_endpoint.call_with_http_info(**kwargs)

    def downgrade_org(
        self,
        public_id: str,
    ) -> OrgDowngradedResponse:
        """Spin-off Child Organization.

        Only available for MSP customers. Removes a child organization from the hierarchy of the master organization and places the child organization on a 30-day trial.

        :param public_id: The ``public_id`` of the organization you are operating within.
        :type public_id: str
        :rtype: OrgDowngradedResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        return self._downgrade_org_endpoint.call_with_http_info(**kwargs)

    def get_org(
        self,
        public_id: str,
    ) -> OrganizationResponse:
        """Get organization information.

        Get organization information.

        :param public_id: The ``public_id`` of the organization you are operating within.
        :type public_id: str
        :rtype: OrganizationResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        return self._get_org_endpoint.call_with_http_info(**kwargs)

    def list_orgs(
        self,
    ) -> OrganizationListResponse:
        """List your managed organizations.

        This endpoint returns data on your top-level organization.

        :rtype: OrganizationListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_orgs_endpoint.call_with_http_info(**kwargs)

    def update_org(
        self,
        public_id: str,
        body: Organization,
    ) -> OrganizationResponse:
        """Update your organization.

        Update your organization.

        :param public_id: The ``public_id`` of the organization you are operating within.
        :type public_id: str
        :type body: Organization
        :rtype: OrganizationResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        kwargs["body"] = body

        return self._update_org_endpoint.call_with_http_info(**kwargs)

    def upload_idp_for_org(
        self,
        public_id: str,
        idp_file: file_type,
    ) -> IdpResponse:
        """Upload IdP metadata.

        There are a couple of options for updating the Identity Provider (IdP)
        metadata from your SAML IdP.

        *
          **Multipart Form-Data** : Post the IdP metadata file using a form post.

        *
          **XML Body:** Post the IdP metadata file as the body of the request.

        :param public_id: The ``public_id`` of the organization you are operating with
        :type public_id: str
        :param idp_file: The path to the XML metadata file you wish to upload.
        :type idp_file: file_type
        :rtype: IdpResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        kwargs["idp_file"] = idp_file

        return self._upload_idp_for_org_endpoint.call_with_http_info(**kwargs)



"""
Update an SLO correction returns "OK" response
"""

from datetime import datetime
from dateutil.relativedelta import relativedelta
from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objective_corrections_api import ServiceLevelObjectiveCorrectionsApi
from datadog_api_client.v1.model.slo_correction_category import SLOCorrectionCategory
from datadog_api_client.v1.model.slo_correction_type import SLOCorrectionType
from datadog_api_client.v1.model.slo_correction_update_data import SLOCorrectionUpdateData
from datadog_api_client.v1.model.slo_correction_update_request import SLOCorrectionUpdateRequest
from datadog_api_client.v1.model.slo_correction_update_request_attributes import SLOCorrectionUpdateRequestAttributes

# there is a valid "correction" for "slo"
CORRECTION_DATA_ID = environ["CORRECTION_DATA_ID"]

body = SLOCorrectionUpdateRequest(
    data=SLOCorrectionUpdateData(
        attributes=SLOCorrectionUpdateRequestAttributes(
            category=SLOCorrectionCategory.DEPLOYMENT,
            description="Example-Update_an_SLO_correction_returns_OK_response",
            end=int((datetime.now() + relativedelta(hours=1)).timestamp()),
            start=int(datetime.now().timestamp()),
            timezone="UTC",
        ),
        type=SLOCorrectionType.CORRECTION,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectiveCorrectionsApi(api_client)
    response = api_instance.update_slo_correction(slo_correction_id=CORRECTION_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
    from datadog_api_client.v1.model.synthetics_test_execution_rule import SyntheticsTestExecutionRule
    from datadog_api_client.v1.model.synthetics_status import SyntheticsStatus
    from datadog_api_client.v1.model.synthetics_test_details_type import SyntheticsTestDetailsType


class SyntheticsBatchResult(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
        from datadog_api_client.v1.model.synthetics_test_execution_rule import SyntheticsTestExecutionRule
        from datadog_api_client.v1.model.synthetics_status import SyntheticsStatus
        from datadog_api_client.v1.model.synthetics_test_details_type import SyntheticsTestDetailsType

        return {
            "device": (SyntheticsDeviceID,),
            "duration": (float,),
            "execution_rule": (SyntheticsTestExecutionRule,),
            "location": (str,),
            "result_id": (str,),
            "retries": (float,),
            "status": (SyntheticsStatus,),
            "test_name": (str,),
            "test_public_id": (str,),
            "test_type": (SyntheticsTestDetailsType,),
        }

    attribute_map = {
        "device": "device",
        "duration": "duration",
        "execution_rule": "execution_rule",
        "location": "location",
        "result_id": "result_id",
        "retries": "retries",
        "status": "status",
        "test_name": "test_name",
        "test_public_id": "test_public_id",
        "test_type": "test_type",
    }

    def __init__(
        self_,
        device: Union[SyntheticsDeviceID, UnsetType] = unset,
        duration: Union[float, UnsetType] = unset,
        execution_rule: Union[SyntheticsTestExecutionRule, UnsetType] = unset,
        location: Union[str, UnsetType] = unset,
        result_id: Union[str, UnsetType] = unset,
        retries: Union[float, UnsetType] = unset,
        status: Union[SyntheticsStatus, UnsetType] = unset,
        test_name: Union[str, UnsetType] = unset,
        test_public_id: Union[str, UnsetType] = unset,
        test_type: Union[SyntheticsTestDetailsType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object with the results of a Synthetics batch.

        :param device: The device ID.
        :type device: SyntheticsDeviceID, optional

        :param duration: Total duration in millisecond of the test.
        :type duration: float, optional

        :param execution_rule: Execution rule for a Synthetics test.
        :type execution_rule: SyntheticsTestExecutionRule, optional

        :param location: Name of the location.
        :type location: str, optional

        :param result_id: The ID of the result to get.
        :type result_id: str, optional

        :param retries: Number of times this result has been retried.
        :type retries: float, optional

        :param status: Determines whether or not the batch has passed, failed, or is in progress.
        :type status: SyntheticsStatus, optional

        :param test_name: Name of the test.
        :type test_name: str, optional

        :param test_public_id: The public ID of the Synthetic test.
        :type test_public_id: str, optional

        :param test_type: Type of the Synthetic test, either ``api`` or ``browser``.
        :type test_type: SyntheticsTestDetailsType, optional
        """
        if device is not unset:
            kwargs["device"] = device
        if duration is not unset:
            kwargs["duration"] = duration
        if execution_rule is not unset:
            kwargs["execution_rule"] = execution_rule
        if location is not unset:
            kwargs["location"] = location
        if result_id is not unset:
            kwargs["result_id"] = result_id
        if retries is not unset:
            kwargs["retries"] = retries
        if status is not unset:
            kwargs["status"] = status
        if test_name is not unset:
            kwargs["test_name"] = test_name
        if test_public_id is not unset:
            kwargs["test_public_id"] = test_public_id
        if test_type is not unset:
            kwargs["test_type"] = test_type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class GraphSnapshot(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "graph_def": (str,),
            "metric_query": (str,),
            "snapshot_url": (str,),
        }

    attribute_map = {
        "graph_def": "graph_def",
        "metric_query": "metric_query",
        "snapshot_url": "snapshot_url",
    }

    def __init__(
        self_,
        graph_def: Union[str, UnsetType] = unset,
        metric_query: Union[str, UnsetType] = unset,
        snapshot_url: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object representing a graph snapshot.

        :param graph_def: A JSON document defining the graph. ``graph_def`` can be used instead of ``metric_query``.
            The JSON document uses the `grammar defined here <https://docs.datadoghq.com/graphing/graphing_json/#grammar>`_
            and should be formatted to a single line then URL encoded.
        :type graph_def: str, optional

        :param metric_query: The metric query. One of ``metric_query`` or ``graph_def`` is required.
        :type metric_query: str, optional

        :param snapshot_url: URL of your `graph snapshot <https://docs.datadoghq.com/metrics/explorer/#snapshot>`_.
        :type snapshot_url: str, optional
        """
        if graph_def is not unset:
            kwargs["graph_def"] = graph_def
        if metric_query is not unset:
            kwargs["metric_query"] = metric_query
        if snapshot_url is not unset:
            kwargs["snapshot_url"] = snapshot_url
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SLOCorrectionCategory(ModelSimple):
    """
    Category the SLO correction belongs to.

    :param value: Must be one of ["Scheduled Maintenance", "Outside Business Hours", "Deployment", "Other"].
    :type value: str
    """

    allowed_values = {
        "Scheduled Maintenance",
        "Outside Business Hours",
        "Deployment",
        "Other",
    }
    SCHEDULED_MAINTENANCE: ClassVar["SLOCorrectionCategory"]
    OUTSIDE_BUSINESS_HOURS: ClassVar["SLOCorrectionCategory"]
    DEPLOYMENT: ClassVar["SLOCorrectionCategory"]
    OTHER: ClassVar["SLOCorrectionCategory"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SLOCorrectionCategory.SCHEDULED_MAINTENANCE = SLOCorrectionCategory("Scheduled Maintenance")
SLOCorrectionCategory.OUTSIDE_BUSINESS_HOURS = SLOCorrectionCategory("Outside Business Hours")
SLOCorrectionCategory.DEPLOYMENT = SLOCorrectionCategory("Deployment")
SLOCorrectionCategory.OTHER = SLOCorrectionCategory("Other")



"""
Edit a monitor returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.monitors_api import MonitorsApi
from datadog_api_client.v1.model.monitor_options import MonitorOptions
from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
from datadog_api_client.v1.model.monitor_update_request import MonitorUpdateRequest

# there is a valid "monitor" in the system
MONITOR_ID = environ["MONITOR_ID"]
MONITOR_NAME = environ["MONITOR_NAME"]

body = MonitorUpdateRequest(
    name="My monitor-updated",
    options=MonitorOptions(
        evaluation_delay=None,
        new_group_delay=600,
        new_host_delay=None,
        renotify_interval=None,
        thresholds=MonitorThresholds(
            critical=2.0,
            warning=None,
        ),
        timeout_h=None,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MonitorsApi(api_client)
    response = api_instance.update_monitor(monitor_id=int(MONITOR_ID), body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsStatus(ModelSimple):
    """
    Determines whether or not the batch has passed, failed, or is in progress.

    :param value: Must be one of ["passed", "skipped", "failed"].
    :type value: str
    """

    allowed_values = {
        "passed",
        "skipped",
        "failed",
    }
    PASSED: ClassVar["SyntheticsStatus"]
    skipped: ClassVar["SyntheticsStatus"]
    failed: ClassVar["SyntheticsStatus"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsStatus.PASSED = SyntheticsStatus("passed")
SyntheticsStatus.skipped = SyntheticsStatus("skipped")
SyntheticsStatus.failed = SyntheticsStatus("failed")



"""
Create, update, and delete incident attachments returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incidents_api import IncidentsApi
from datadog_api_client.v2.model.incident_attachment_link_attachment_type import IncidentAttachmentLinkAttachmentType
from datadog_api_client.v2.model.incident_attachment_link_attributes import IncidentAttachmentLinkAttributes
from datadog_api_client.v2.model.incident_attachment_link_attributes_attachment_object import (
    IncidentAttachmentLinkAttributesAttachmentObject,
)
from datadog_api_client.v2.model.incident_attachment_postmortem_attachment_type import (
    IncidentAttachmentPostmortemAttachmentType,
)
from datadog_api_client.v2.model.incident_attachment_postmortem_attributes import IncidentAttachmentPostmortemAttributes
from datadog_api_client.v2.model.incident_attachment_type import IncidentAttachmentType
from datadog_api_client.v2.model.incident_attachment_update_data import IncidentAttachmentUpdateData
from datadog_api_client.v2.model.incident_attachment_update_request import IncidentAttachmentUpdateRequest
from datadog_api_client.v2.model.incident_attachments_postmortem_attributes_attachment_object import (
    IncidentAttachmentsPostmortemAttributesAttachmentObject,
)

body = IncidentAttachmentUpdateRequest(
    data=[
        IncidentAttachmentUpdateData(
            attributes=IncidentAttachmentPostmortemAttributes(
                attachment=IncidentAttachmentsPostmortemAttributesAttachmentObject(
                    document_url="https://app.datadoghq.com/notebook/123",
                    title="Postmortem IR-123",
                ),
                attachment_type=IncidentAttachmentPostmortemAttachmentType.POSTMORTEM,
            ),
            id="00000000-abcd-0002-0000-000000000000",
            type=IncidentAttachmentType.INCIDENT_ATTACHMENTS,
        ),
        IncidentAttachmentUpdateData(
            attributes=IncidentAttachmentLinkAttributes(
                attachment=IncidentAttachmentLinkAttributesAttachmentObject(
                    document_url="https://www.example.com/webstore-failure-runbook",
                    title="Runbook for webstore service failures",
                ),
                attachment_type=IncidentAttachmentLinkAttachmentType.LINK,
            ),
            type=IncidentAttachmentType.INCIDENT_ATTACHMENTS,
        ),
        IncidentAttachmentUpdateData(
            id="00000000-abcd-0003-0000-000000000000",
            type=IncidentAttachmentType.INCIDENT_ATTACHMENTS,
        ),
    ],
)

configuration = Configuration()
configuration.unstable_operations["update_incident_attachments"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentsApi(api_client)
    response = api_instance.update_incident_attachments(incident_id="incident_id", body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class LogsProcessor(ModelComposed):
    def __init__(self, **kwargs):
        """
        Definition of a logs processor.

        :param grok: Set of rules for the grok parser.
        :type grok: LogsGrokParserRules

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param samples: List of sample logs to test this grok parser.
        :type samples: [str], optional

        :param source: Name of the log attribute to parse.
        :type source: str

        :param type: Type of logs grok parser.
        :type type: LogsGrokParserType

        :param sources: Array of source attributes.
        :type sources: [str]

        :param override_on_conflict: Override or not the target element if already set,
        :type override_on_conflict: bool, optional

        :param preserve_source: Remove or preserve the remapped source element.
        :type preserve_source: bool, optional

        :param source_type: Defines if the sources are from log `attribute` or `tag`.
        :type source_type: str, optional

        :param target: Final attribute or tag name to remap the sources to.
        :type target: str

        :param target_format: If the `target_type` of the remapper is `attribute`, try to cast the value to a new specific type.
            If the cast is not possible, the original type is kept. `string`, `integer`, or `double` are the possible types.
            If the `target_type` is `tag`, this parameter may not be specified.
        :type target_format: TargetFormatType, optional

        :param target_type: Defines if the final attribute or tag name is from log `attribute` or `tag`.
        :type target_type: str, optional

        :param normalize_ending_slashes: Normalize the ending slashes or not.
        :type normalize_ending_slashes: bool, none_type, optional

        :param is_encoded: Define if the source attribute is URL encoded or not.
        :type is_encoded: bool, optional

        :param categories: Array of filters to match or not a log and their
            corresponding `name` to assign a custom value to the log.
        :type categories: [LogsCategoryProcessorCategory]

        :param expression: Arithmetic operation between one or more log attributes.
        :type expression: str

        :param is_replace_missing: If `true`, it replaces all missing attributes of expression by `0`, `false`
            skip the operation if an attribute is missing.
        :type is_replace_missing: bool, optional

        :param template: A formula with one or more attributes and raw text.
        :type template: str

        :param filter: Filter for logs.
        :type filter: LogsFilter, optional

        :param processors: Ordered list of processors in this pipeline.
        :type processors: [LogsProcessor], optional

        :param default_lookup: Value to set the target attribute if the source value is not found in the list.
        :type default_lookup: str, optional

        :param lookup_table: Mapping table of values for the source attribute and their associated target attribute values,
            formatted as `["source_key1,target_value1", "source_key2,target_value2"]`
        :type lookup_table: [str]

        :param lookup_enrichment_table: Name of the Reference Table for the source attribute and their associated target attribute values.
        :type lookup_enrichment_table: str
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v1.model.logs_grok_parser import LogsGrokParser
        from datadog_api_client.v1.model.logs_date_remapper import LogsDateRemapper
        from datadog_api_client.v1.model.logs_status_remapper import LogsStatusRemapper
        from datadog_api_client.v1.model.logs_service_remapper import LogsServiceRemapper
        from datadog_api_client.v1.model.logs_message_remapper import LogsMessageRemapper
        from datadog_api_client.v1.model.logs_attribute_remapper import LogsAttributeRemapper
        from datadog_api_client.v1.model.logs_url_parser import LogsURLParser
        from datadog_api_client.v1.model.logs_user_agent_parser import LogsUserAgentParser
        from datadog_api_client.v1.model.logs_category_processor import LogsCategoryProcessor
        from datadog_api_client.v1.model.logs_arithmetic_processor import LogsArithmeticProcessor
        from datadog_api_client.v1.model.logs_string_builder_processor import LogsStringBuilderProcessor
        from datadog_api_client.v1.model.logs_pipeline_processor import LogsPipelineProcessor
        from datadog_api_client.v1.model.logs_geo_ip_parser import LogsGeoIPParser
        from datadog_api_client.v1.model.logs_lookup_processor import LogsLookupProcessor
        from datadog_api_client.v1.model.reference_table_logs_lookup_processor import ReferenceTableLogsLookupProcessor
        from datadog_api_client.v1.model.logs_trace_remapper import LogsTraceRemapper

        return {
            "oneOf": [
                LogsGrokParser,
                LogsDateRemapper,
                LogsStatusRemapper,
                LogsServiceRemapper,
                LogsMessageRemapper,
                LogsAttributeRemapper,
                LogsURLParser,
                LogsUserAgentParser,
                LogsCategoryProcessor,
                LogsArithmeticProcessor,
                LogsStringBuilderProcessor,
                LogsPipelineProcessor,
                LogsGeoIPParser,
                LogsLookupProcessor,
                ReferenceTableLogsLookupProcessor,
                LogsTraceRemapper,
            ],
        }



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsGlobalVariableParseTestOptionsType(ModelSimple):
    """
    Property of the Synthetics Test Response to use for a Synthetics global variable.

    :param value: Must be one of ["http_body", "http_header", "local_variable"].
    :type value: str
    """

    allowed_values = {
        "http_body",
        "http_header",
        "local_variable",
    }
    HTTP_BODY: ClassVar["SyntheticsGlobalVariableParseTestOptionsType"]
    HTTP_HEADER: ClassVar["SyntheticsGlobalVariableParseTestOptionsType"]
    LOCAL_VARIABLE: ClassVar["SyntheticsGlobalVariableParseTestOptionsType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsGlobalVariableParseTestOptionsType.HTTP_BODY = SyntheticsGlobalVariableParseTestOptionsType("http_body")
SyntheticsGlobalVariableParseTestOptionsType.HTTP_HEADER = SyntheticsGlobalVariableParseTestOptionsType("http_header")
SyntheticsGlobalVariableParseTestOptionsType.LOCAL_VARIABLE = SyntheticsGlobalVariableParseTestOptionsType(
    "local_variable"
)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_warning_type import SyntheticsWarningType


class SyntheticsStepDetailWarning(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_warning_type import SyntheticsWarningType

        return {
            "message": (str,),
            "type": (SyntheticsWarningType,),
        }

    attribute_map = {
        "message": "message",
        "type": "type",
    }

    def __init__(self_, message: str, type: SyntheticsWarningType, **kwargs):
        """
        Object collecting warnings for a given step.

        :param message: Message for the warning.
        :type message: str

        :param type: User locator used.
        :type type: SyntheticsWarningType
        """
        super().__init__(kwargs)

        self_.message = message
        self_.type = type



"""
Get organization information returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.organizations_api import OrganizationsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = OrganizationsApi(api_client)
    response = api_instance.get_org(
        public_id="abc123",
    )

    print(response)



"""
Validate a monitor returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.monitors_api import MonitorsApi
from datadog_api_client.v1.model.monitor import Monitor
from datadog_api_client.v1.model.monitor_options import MonitorOptions
from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
from datadog_api_client.v1.model.monitor_type import MonitorType
from datadog_api_client.v1.model.on_missing_data_option import OnMissingDataOption

body = Monitor(
    name="Example-Validate_a_monitor_returns_OK_response",
    type=MonitorType.LOG_ALERT,
    query='logs("service:foo AND type:error").index("main").rollup("count").by("source").last("5m") > 2',
    message="some message Notify: @hipchat-channel",
    tags=[
        "test:examplevalidateamonitorreturnsokresponse",
        "env:ci",
    ],
    priority=3,
    options=MonitorOptions(
        enable_logs_sample=True,
        escalation_message="the situation has escalated",
        evaluation_delay=700,
        groupby_simple_monitor=True,
        include_tags=True,
        locked=False,
        new_host_delay=600,
        no_data_timeframe=None,
        notify_audit=False,
        notify_no_data=False,
        on_missing_data=OnMissingDataOption.SHOW_AND_NOTIFY_NO_DATA,
        renotify_interval=60,
        require_full_window=True,
        timeout_h=24,
        thresholds=MonitorThresholds(
            critical=2.0,
            warning=1.0,
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MonitorsApi(api_client)
    response = api_instance.validate_monitor(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v2.model.logs_archive_order import LogsArchiveOrder
from datadog_api_client.v2.model.logs_archives import LogsArchives
from datadog_api_client.v2.model.logs_archive import LogsArchive
from datadog_api_client.v2.model.logs_archive_create_request import LogsArchiveCreateRequest
from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole
from datadog_api_client.v2.model.roles_response import RolesResponse


class LogsArchivesApi:
    """
    Archives forward all the logs ingested to a cloud storage system.

    See the `Archives Page <https://app.datadoghq.com/logs/pipelines/archives>`_
    for a list of the archives currently configured in web UI.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._add_read_role_to_archive_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/archives/{archive_id}/readers",
                "operation_id": "add_read_role_to_archive",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "archive_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "archive_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (RelationshipToRole,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["*/*"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_logs_archive_endpoint = _Endpoint(
            settings={
                "response_type": (LogsArchive,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/archives",
                "operation_id": "create_logs_archive",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (LogsArchiveCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_logs_archive_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/archives/{archive_id}",
                "operation_id": "delete_logs_archive",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "archive_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "archive_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_logs_archive_endpoint = _Endpoint(
            settings={
                "response_type": (LogsArchive,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/logs/config/archives/{archive_id}",
                "operation_id": "get_logs_archive",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "archive_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "archive_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_logs_archive_order_endpoint = _Endpoint(
            settings={
                "response_type": (LogsArchiveOrder,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/logs/config/archive-order",
                "operation_id": "get_logs_archive_order",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_archive_read_roles_endpoint = _Endpoint(
            settings={
                "response_type": (RolesResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/logs/config/archives/{archive_id}/readers",
                "operation_id": "list_archive_read_roles",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "archive_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "archive_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_logs_archives_endpoint = _Endpoint(
            settings={
                "response_type": (LogsArchives,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/logs/config/archives",
                "operation_id": "list_logs_archives",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._remove_role_from_archive_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/archives/{archive_id}/readers",
                "operation_id": "remove_role_from_archive",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "archive_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "archive_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (RelationshipToRole,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["*/*"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_logs_archive_endpoint = _Endpoint(
            settings={
                "response_type": (LogsArchive,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/archives/{archive_id}",
                "operation_id": "update_logs_archive",
                "http_method": "PUT",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "archive_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "archive_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (LogsArchiveCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_logs_archive_order_endpoint = _Endpoint(
            settings={
                "response_type": (LogsArchiveOrder,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/archive-order",
                "operation_id": "update_logs_archive_order",
                "http_method": "PUT",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (LogsArchiveOrder,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def add_read_role_to_archive(
        self,
        archive_id: str,
        body: RelationshipToRole,
    ) -> None:
        """Grant role to an archive.

        Adds a read role to an archive. ( `Roles API <https://docs.datadoghq.com/api/v2/roles/>`_ )

        :param archive_id: The ID of the archive.
        :type archive_id: str
        :type body: RelationshipToRole
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["archive_id"] = archive_id

        kwargs["body"] = body

        return self._add_read_role_to_archive_endpoint.call_with_http_info(**kwargs)

    def create_logs_archive(
        self,
        body: LogsArchiveCreateRequest,
    ) -> LogsArchive:
        """Create an archive.

        Create an archive in your organization.

        :param body: The definition of the new archive.
        :type body: LogsArchiveCreateRequest
        :rtype: LogsArchive
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_logs_archive_endpoint.call_with_http_info(**kwargs)

    def delete_logs_archive(
        self,
        archive_id: str,
    ) -> None:
        """Delete an archive.

        Delete a given archive from your organization.

        :param archive_id: The ID of the archive.
        :type archive_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["archive_id"] = archive_id

        return self._delete_logs_archive_endpoint.call_with_http_info(**kwargs)

    def get_logs_archive(
        self,
        archive_id: str,
    ) -> LogsArchive:
        """Get an archive.

        Get a specific archive from your organization.

        :param archive_id: The ID of the archive.
        :type archive_id: str
        :rtype: LogsArchive
        """
        kwargs: Dict[str, Any] = {}
        kwargs["archive_id"] = archive_id

        return self._get_logs_archive_endpoint.call_with_http_info(**kwargs)

    def get_logs_archive_order(
        self,
    ) -> LogsArchiveOrder:
        """Get archive order.

        Get the current order of your archives.
        This endpoint takes no JSON arguments.

        :rtype: LogsArchiveOrder
        """
        kwargs: Dict[str, Any] = {}
        return self._get_logs_archive_order_endpoint.call_with_http_info(**kwargs)

    def list_archive_read_roles(
        self,
        archive_id: str,
    ) -> RolesResponse:
        """List read roles for an archive.

        Returns all read roles a given archive is restricted to.

        :param archive_id: The ID of the archive.
        :type archive_id: str
        :rtype: RolesResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["archive_id"] = archive_id

        return self._list_archive_read_roles_endpoint.call_with_http_info(**kwargs)

    def list_logs_archives(
        self,
    ) -> LogsArchives:
        """Get all archives.

        Get the list of configured logs archives with their definitions.

        :rtype: LogsArchives
        """
        kwargs: Dict[str, Any] = {}
        return self._list_logs_archives_endpoint.call_with_http_info(**kwargs)

    def remove_role_from_archive(
        self,
        archive_id: str,
        body: RelationshipToRole,
    ) -> None:
        """Revoke role from an archive.

        Removes a role from an archive. ( `Roles API <https://docs.datadoghq.com/api/v2/roles/>`_ )

        :param archive_id: The ID of the archive.
        :type archive_id: str
        :type body: RelationshipToRole
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["archive_id"] = archive_id

        kwargs["body"] = body

        return self._remove_role_from_archive_endpoint.call_with_http_info(**kwargs)

    def update_logs_archive(
        self,
        archive_id: str,
        body: LogsArchiveCreateRequest,
    ) -> LogsArchive:
        """Update an archive.

        Update a given archive configuration.

        **Note** : Using this method updates your archive configuration by **replacing**
        your current configuration with the new one sent to your Datadog organization.

        :param archive_id: The ID of the archive.
        :type archive_id: str
        :param body: New definition of the archive.
        :type body: LogsArchiveCreateRequest
        :rtype: LogsArchive
        """
        kwargs: Dict[str, Any] = {}
        kwargs["archive_id"] = archive_id

        kwargs["body"] = body

        return self._update_logs_archive_endpoint.call_with_http_info(**kwargs)

    def update_logs_archive_order(
        self,
        body: LogsArchiveOrder,
    ) -> LogsArchiveOrder:
        """Update archive order.

        Update the order of your archives. Since logs are processed sequentially, reordering an archive may change
        the structure and content of the data processed by other archives.

        **Note** : Using the ``PUT`` method updates your archive's order by replacing the current order
        with the new one.

        :param body: An object containing the new ordered list of archive IDs.
        :type body: LogsArchiveOrder
        :rtype: LogsArchiveOrder
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._update_logs_archive_order_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_filter import LogsFilter


class LogsCategoryProcessorCategory(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_filter import LogsFilter

        return {
            "filter": (LogsFilter,),
            "name": (str,),
        }

    attribute_map = {
        "filter": "filter",
        "name": "name",
    }

    def __init__(self_, filter: Union[LogsFilter, UnsetType] = unset, name: Union[str, UnsetType] = unset, **kwargs):
        """
        Object describing the logs filter.

        :param filter: Filter for logs.
        :type filter: LogsFilter, optional

        :param name: Value to assign to the target attribute.
        :type name: str, optional
        """
        if filter is not unset:
            kwargs["filter"] = filter
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class IFrameWidgetDefinitionType(ModelSimple):
    """
    Type of the iframe widget.

    :param value: If omitted defaults to "iframe". Must be one of ["iframe"].
    :type value: str
    """

    allowed_values = {
        "iframe",
    }
    IFRAME: ClassVar["IFrameWidgetDefinitionType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


IFrameWidgetDefinitionType.IFRAME = IFrameWidgetDefinitionType("iframe")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_basic_auth import SyntheticsBasicAuth
    from datadog_api_client.v1.model.synthetics_test_request_body_type import SyntheticsTestRequestBodyType
    from datadog_api_client.v1.model.synthetics_test_call_type import SyntheticsTestCallType
    from datadog_api_client.v1.model.synthetics_test_request_certificate import SyntheticsTestRequestCertificate
    from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
    from datadog_api_client.v1.model.synthetics_test_metadata import SyntheticsTestMetadata
    from datadog_api_client.v1.model.synthetics_test_request_proxy import SyntheticsTestRequestProxy
    from datadog_api_client.v1.model.synthetics_basic_auth_web import SyntheticsBasicAuthWeb
    from datadog_api_client.v1.model.synthetics_basic_auth_sigv4 import SyntheticsBasicAuthSigv4
    from datadog_api_client.v1.model.synthetics_basic_auth_ntlm import SyntheticsBasicAuthNTLM
    from datadog_api_client.v1.model.synthetics_basic_auth_digest import SyntheticsBasicAuthDigest
    from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client import SyntheticsBasicAuthOauthClient
    from datadog_api_client.v1.model.synthetics_basic_auth_oauth_rop import SyntheticsBasicAuthOauthROP


class SyntheticsTestRequest(ModelNormal):
    validations = {
        "dns_server_port": {
            "inclusive_maximum": 65535,
            "inclusive_minimum": 1,
        },
        "number_of_packets": {
            "inclusive_maximum": 10,
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_basic_auth import SyntheticsBasicAuth
        from datadog_api_client.v1.model.synthetics_test_request_body_type import SyntheticsTestRequestBodyType
        from datadog_api_client.v1.model.synthetics_test_call_type import SyntheticsTestCallType
        from datadog_api_client.v1.model.synthetics_test_request_certificate import SyntheticsTestRequestCertificate
        from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
        from datadog_api_client.v1.model.synthetics_test_metadata import SyntheticsTestMetadata
        from datadog_api_client.v1.model.synthetics_test_request_proxy import SyntheticsTestRequestProxy

        return {
            "allow_insecure": (bool,),
            "basic_auth": (SyntheticsBasicAuth,),
            "body": (str,),
            "body_type": (SyntheticsTestRequestBodyType,),
            "call_type": (SyntheticsTestCallType,),
            "certificate": (SyntheticsTestRequestCertificate,),
            "certificate_domains": ([str],),
            "dns_server": (str,),
            "dns_server_port": (int,),
            "follow_redirects": (bool,),
            "headers": (SyntheticsTestHeaders,),
            "host": (str,),
            "message": (str,),
            "metadata": (SyntheticsTestMetadata,),
            "method": (str,),
            "no_saving_response_body": (bool,),
            "number_of_packets": (int,),
            "port": (int,),
            "proxy": (SyntheticsTestRequestProxy,),
            "query": (dict,),
            "servername": (str,),
            "service": (str,),
            "should_track_hops": (bool,),
            "timeout": (float,),
            "url": (str,),
        }

    attribute_map = {
        "allow_insecure": "allow_insecure",
        "basic_auth": "basicAuth",
        "body": "body",
        "body_type": "bodyType",
        "call_type": "callType",
        "certificate": "certificate",
        "certificate_domains": "certificateDomains",
        "dns_server": "dnsServer",
        "dns_server_port": "dnsServerPort",
        "follow_redirects": "follow_redirects",
        "headers": "headers",
        "host": "host",
        "message": "message",
        "metadata": "metadata",
        "method": "method",
        "no_saving_response_body": "noSavingResponseBody",
        "number_of_packets": "numberOfPackets",
        "port": "port",
        "proxy": "proxy",
        "query": "query",
        "servername": "servername",
        "service": "service",
        "should_track_hops": "shouldTrackHops",
        "timeout": "timeout",
        "url": "url",
    }

    def __init__(
        self_,
        allow_insecure: Union[bool, UnsetType] = unset,
        basic_auth: Union[
            SyntheticsBasicAuth,
            SyntheticsBasicAuthWeb,
            SyntheticsBasicAuthSigv4,
            SyntheticsBasicAuthNTLM,
            SyntheticsBasicAuthDigest,
            SyntheticsBasicAuthOauthClient,
            SyntheticsBasicAuthOauthROP,
            UnsetType,
        ] = unset,
        body: Union[str, UnsetType] = unset,
        body_type: Union[SyntheticsTestRequestBodyType, UnsetType] = unset,
        call_type: Union[SyntheticsTestCallType, UnsetType] = unset,
        certificate: Union[SyntheticsTestRequestCertificate, UnsetType] = unset,
        certificate_domains: Union[List[str], UnsetType] = unset,
        dns_server: Union[str, UnsetType] = unset,
        dns_server_port: Union[int, UnsetType] = unset,
        follow_redirects: Union[bool, UnsetType] = unset,
        headers: Union[SyntheticsTestHeaders, UnsetType] = unset,
        host: Union[str, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        metadata: Union[SyntheticsTestMetadata, UnsetType] = unset,
        method: Union[str, UnsetType] = unset,
        no_saving_response_body: Union[bool, UnsetType] = unset,
        number_of_packets: Union[int, UnsetType] = unset,
        port: Union[int, UnsetType] = unset,
        proxy: Union[SyntheticsTestRequestProxy, UnsetType] = unset,
        query: Union[dict, UnsetType] = unset,
        servername: Union[str, UnsetType] = unset,
        service: Union[str, UnsetType] = unset,
        should_track_hops: Union[bool, UnsetType] = unset,
        timeout: Union[float, UnsetType] = unset,
        url: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object describing the Synthetic test request.

        :param allow_insecure: Allows loading insecure content for an HTTP request in a multistep test step.
        :type allow_insecure: bool, optional

        :param basic_auth: Object to handle basic authentication when performing the test.
        :type basic_auth: SyntheticsBasicAuth, optional

        :param body: Body to include in the test.
        :type body: str, optional

        :param body_type: Type of the request body.
        :type body_type: SyntheticsTestRequestBodyType, optional

        :param call_type: The type of gRPC call to perform.
        :type call_type: SyntheticsTestCallType, optional

        :param certificate: Client certificate to use when performing the test request.
        :type certificate: SyntheticsTestRequestCertificate, optional

        :param certificate_domains: By default, the client certificate is applied on the domain of the starting URL for browser tests. If you want your client certificate to be applied on other domains instead, add them in ``certificateDomains``.
        :type certificate_domains: [str], optional

        :param dns_server: DNS server to use for DNS tests.
        :type dns_server: str, optional

        :param dns_server_port: DNS server port to use for DNS tests.
        :type dns_server_port: int, optional

        :param follow_redirects: Specifies whether or not the request follows redirects.
        :type follow_redirects: bool, optional

        :param headers: Headers to include when performing the test.
        :type headers: SyntheticsTestHeaders, optional

        :param host: Host name to perform the test with.
        :type host: str, optional

        :param message: Message to send for UDP or WebSocket tests.
        :type message: str, optional

        :param metadata: Metadata to include when performing the gRPC test.
        :type metadata: SyntheticsTestMetadata, optional

        :param method: Either the HTTP method/verb to use or a gRPC method available on the service set in the ``service`` field. Required if ``subtype`` is ``HTTP`` or if ``subtype`` is ``grpc`` and ``callType`` is ``unary``.
        :type method: str, optional

        :param no_saving_response_body: Determines whether or not to save the response body.
        :type no_saving_response_body: bool, optional

        :param number_of_packets: Number of pings to use per test.
        :type number_of_packets: int, optional

        :param port: Port to use when performing the test.
        :type port: int, optional

        :param proxy: The proxy to perform the test.
        :type proxy: SyntheticsTestRequestProxy, optional

        :param query: Query to use for the test.
        :type query: dict, optional

        :param servername: For SSL tests, it specifies on which server you want to initiate the TLS handshake,
            allowing the server to present one of multiple possible certificates on
            the same IP address and TCP port number.
        :type servername: str, optional

        :param service: The gRPC service on which you want to perform the gRPC call.
        :type service: str, optional

        :param should_track_hops: Turns on a traceroute probe to discover all gateways along the path to the host destination.
        :type should_track_hops: bool, optional

        :param timeout: Timeout in seconds for the test.
        :type timeout: float, optional

        :param url: URL to perform the test with.
        :type url: str, optional
        """
        if allow_insecure is not unset:
            kwargs["allow_insecure"] = allow_insecure
        if basic_auth is not unset:
            kwargs["basic_auth"] = basic_auth
        if body is not unset:
            kwargs["body"] = body
        if body_type is not unset:
            kwargs["body_type"] = body_type
        if call_type is not unset:
            kwargs["call_type"] = call_type
        if certificate is not unset:
            kwargs["certificate"] = certificate
        if certificate_domains is not unset:
            kwargs["certificate_domains"] = certificate_domains
        if dns_server is not unset:
            kwargs["dns_server"] = dns_server
        if dns_server_port is not unset:
            kwargs["dns_server_port"] = dns_server_port
        if follow_redirects is not unset:
            kwargs["follow_redirects"] = follow_redirects
        if headers is not unset:
            kwargs["headers"] = headers
        if host is not unset:
            kwargs["host"] = host
        if message is not unset:
            kwargs["message"] = message
        if metadata is not unset:
            kwargs["metadata"] = metadata
        if method is not unset:
            kwargs["method"] = method
        if no_saving_response_body is not unset:
            kwargs["no_saving_response_body"] = no_saving_response_body
        if number_of_packets is not unset:
            kwargs["number_of_packets"] = number_of_packets
        if port is not unset:
            kwargs["port"] = port
        if proxy is not unset:
            kwargs["proxy"] = proxy
        if query is not unset:
            kwargs["query"] = query
        if servername is not unset:
            kwargs["servername"] = servername
        if service is not unset:
            kwargs["service"] = service
        if should_track_hops is not unset:
            kwargs["should_track_hops"] = should_track_hops
        if timeout is not unset:
            kwargs["timeout"] = timeout
        if url is not unset:
            kwargs["url"] = url
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SecurityMonitoringTriageUser(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "handle": (str,),
            "id": (int,),
            "name": (str,),
            "uuid": (str,),
        }

    attribute_map = {
        "handle": "handle",
        "id": "id",
        "name": "name",
        "uuid": "uuid",
    }

    def __init__(
        self_,
        uuid: str,
        handle: Union[str, UnsetType] = unset,
        id: Union[int, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object representing a given user entity.

        :param handle: The handle for this user account.
        :type handle: str, optional

        :param id: Numerical ID assigned by Datadog to this user account.
        :type id: int, optional

        :param name: The name for this user account.
        :type name: str, optional

        :param uuid: UUID assigned by Datadog to this user account.
        :type uuid: str
        """
        if handle is not unset:
            kwargs["handle"] = handle
        if id is not unset:
            kwargs["id"] = id
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.uuid = uuid



"""
Revoke role from an archive returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.logs_archives_api import LogsArchivesApi
from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole
from datadog_api_client.v2.model.relationship_to_role_data import RelationshipToRoleData
from datadog_api_client.v2.model.roles_type import RolesType

body = RelationshipToRole(
    data=RelationshipToRoleData(
        id="3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
        type=RolesType.ROLES,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsArchivesApi(api_client)
    api_instance.remove_role_from_archive(archive_id="archive_id", body=body)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
    unset,
    UnsetType,
)


class SecurityMonitoringSignalAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "attributes": (
                {
                    str: (
                        bool,
                        date,
                        datetime,
                        dict,
                        float,
                        int,
                        list,
                        str,
                        none_type,
                    )
                },
            ),
            "message": (str,),
            "tags": ([str],),
            "timestamp": (datetime,),
        }

    attribute_map = {
        "attributes": "attributes",
        "message": "message",
        "tags": "tags",
        "timestamp": "timestamp",
    }

    def __init__(
        self_,
        attributes: Union[Dict[str, Any], UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        timestamp: Union[datetime, UnsetType] = unset,
        **kwargs,
    ):
        """
        The object containing all signal attributes and their
        associated values.

        :param attributes: A JSON object of attributes in the security signal.
        :type attributes: {str: (bool, date, datetime, dict, float, int, list, str, none_type,)}, optional

        :param message: The message in the security signal defined by the rule that generated the signal.
        :type message: str, optional

        :param tags: An array of tags associated with the security signal.
        :type tags: [str], optional

        :param timestamp: The timestamp of the security signal.
        :type timestamp: datetime, optional
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        if message is not unset:
            kwargs["message"] = message
        if tags is not unset:
            kwargs["tags"] = tags
        if timestamp is not unset:
            kwargs["timestamp"] = timestamp
        super().__init__(kwargs)



"""
Aggregate pipelines events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.ci_visibility_pipelines_api import CIVisibilityPipelinesApi
from datadog_api_client.v2.model.ci_app_aggregation_function import CIAppAggregationFunction
from datadog_api_client.v2.model.ci_app_compute import CIAppCompute
from datadog_api_client.v2.model.ci_app_compute_type import CIAppComputeType
from datadog_api_client.v2.model.ci_app_pipelines_aggregate_request import CIAppPipelinesAggregateRequest
from datadog_api_client.v2.model.ci_app_pipelines_group_by import CIAppPipelinesGroupBy
from datadog_api_client.v2.model.ci_app_pipelines_query_filter import CIAppPipelinesQueryFilter
from datadog_api_client.v2.model.ci_app_query_options import CIAppQueryOptions
from datadog_api_client.v2.model.ci_app_query_page_options import CIAppQueryPageOptions

body = CIAppPipelinesAggregateRequest(
    compute=[
        CIAppCompute(
            aggregation=CIAppAggregationFunction.PERCENTILE_90,
            metric="@duration",
            type=CIAppComputeType.TOTAL,
        ),
    ],
    filter=CIAppPipelinesQueryFilter(
        _from="now-15m",
        query="@ci.provider.name:(gitlab OR github)",
        to="now",
    ),
    group_by=[
        CIAppPipelinesGroupBy(
            facet="@ci.status",
            limit=10,
            total=False,
        ),
    ],
    options=CIAppQueryOptions(
        timezone="GMT",
    ),
    page=CIAppQueryPageOptions(
        limit=25,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = CIVisibilityPipelinesApi(api_client)
    response = api_instance.aggregate_ci_app_pipeline_events(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_rule_case import SecurityMonitoringRuleCase
    from datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options import (
        CloudConfigurationRuleComplianceSignalOptions,
    )
    from datadog_api_client.v2.model.security_monitoring_filter import SecurityMonitoringFilter
    from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
    from datadog_api_client.v2.model.security_monitoring_rule_query import SecurityMonitoringRuleQuery
    from datadog_api_client.v2.model.security_monitoring_standard_rule_query import SecurityMonitoringStandardRuleQuery
    from datadog_api_client.v2.model.security_monitoring_signal_rule_query import SecurityMonitoringSignalRuleQuery


class SecurityMonitoringRuleUpdatePayload(ModelNormal):
    validations = {
        "version": {
            "inclusive_maximum": 2147483647,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_rule_case import SecurityMonitoringRuleCase
        from datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options import (
            CloudConfigurationRuleComplianceSignalOptions,
        )
        from datadog_api_client.v2.model.security_monitoring_filter import SecurityMonitoringFilter
        from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
        from datadog_api_client.v2.model.security_monitoring_rule_query import SecurityMonitoringRuleQuery

        return {
            "cases": ([SecurityMonitoringRuleCase],),
            "compliance_signal_options": (CloudConfigurationRuleComplianceSignalOptions,),
            "filters": ([SecurityMonitoringFilter],),
            "has_extended_title": (bool,),
            "is_enabled": (bool,),
            "message": (str,),
            "name": (str,),
            "options": (SecurityMonitoringRuleOptions,),
            "queries": ([SecurityMonitoringRuleQuery],),
            "tags": ([str],),
            "version": (int,),
        }

    attribute_map = {
        "cases": "cases",
        "compliance_signal_options": "complianceSignalOptions",
        "filters": "filters",
        "has_extended_title": "hasExtendedTitle",
        "is_enabled": "isEnabled",
        "message": "message",
        "name": "name",
        "options": "options",
        "queries": "queries",
        "tags": "tags",
        "version": "version",
    }

    def __init__(
        self_,
        cases: Union[List[SecurityMonitoringRuleCase], UnsetType] = unset,
        compliance_signal_options: Union[CloudConfigurationRuleComplianceSignalOptions, UnsetType] = unset,
        filters: Union[List[SecurityMonitoringFilter], UnsetType] = unset,
        has_extended_title: Union[bool, UnsetType] = unset,
        is_enabled: Union[bool, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        options: Union[SecurityMonitoringRuleOptions, UnsetType] = unset,
        queries: Union[
            List[
                Union[
                    SecurityMonitoringRuleQuery, SecurityMonitoringStandardRuleQuery, SecurityMonitoringSignalRuleQuery
                ]
            ],
            UnsetType,
        ] = unset,
        tags: Union[List[str], UnsetType] = unset,
        version: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Update an existing rule.

        :param cases: Cases for generating signals.
        :type cases: [SecurityMonitoringRuleCase], optional

        :param compliance_signal_options: How to generate compliance signals. Useful for cloud_configuration rules only.
        :type compliance_signal_options: CloudConfigurationRuleComplianceSignalOptions, optional

        :param filters: Additional queries to filter matched events before they are processed.
        :type filters: [SecurityMonitoringFilter], optional

        :param has_extended_title: Whether the notifications include the triggering group-by values in their title.
        :type has_extended_title: bool, optional

        :param is_enabled: Whether the rule is enabled.
        :type is_enabled: bool, optional

        :param message: Message for generated signals.
        :type message: str, optional

        :param name: Name of the rule.
        :type name: str, optional

        :param options: Options on rules.
        :type options: SecurityMonitoringRuleOptions, optional

        :param queries: Queries for selecting logs which are part of the rule.
        :type queries: [SecurityMonitoringRuleQuery], optional

        :param tags: Tags for generated signals.
        :type tags: [str], optional

        :param version: The version of the rule being updated.
        :type version: int, optional
        """
        if cases is not unset:
            kwargs["cases"] = cases
        if compliance_signal_options is not unset:
            kwargs["compliance_signal_options"] = compliance_signal_options
        if filters is not unset:
            kwargs["filters"] = filters
        if has_extended_title is not unset:
            kwargs["has_extended_title"] = has_extended_title
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if message is not unset:
            kwargs["message"] = message
        if name is not unset:
            kwargs["name"] = name
        if options is not unset:
            kwargs["options"] = options
        if queries is not unset:
            kwargs["queries"] = queries
        if tags is not unset:
            kwargs["tags"] = tags
        if version is not unset:
            kwargs["version"] = version
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.api_key import ApiKey


class ApiKeyResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.api_key import ApiKey

        return {
            "api_key": (ApiKey,),
        }

    attribute_map = {
        "api_key": "api_key",
    }

    def __init__(self_, api_key: Union[ApiKey, UnsetType] = unset, **kwargs):
        """
        An API key with its associated metadata.

        :param api_key: Datadog API key.
        :type api_key: ApiKey, optional
        """
        if api_key is not unset:
            kwargs["api_key"] = api_key
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.metric_suggested_aggregations import MetricSuggestedAggregations


class MetricSuggestedTagsAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metric_suggested_aggregations import MetricSuggestedAggregations

        return {
            "active_aggregations": (MetricSuggestedAggregations,),
            "active_tags": ([str],),
        }

    attribute_map = {
        "active_aggregations": "active_aggregations",
        "active_tags": "active_tags",
    }

    def __init__(
        self_,
        active_aggregations: Union[MetricSuggestedAggregations, UnsetType] = unset,
        active_tags: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing the definition of a metric's actively queried tags and aggregations.

        :param active_aggregations: List of aggregation combinations that have been actively queried.
        :type active_aggregations: MetricSuggestedAggregations, optional

        :param active_tags: List of tag keys that have been actively queried.
        :type active_tags: [str], optional
        """
        if active_aggregations is not unset:
            kwargs["active_aggregations"] = active_aggregations
        if active_tags is not unset:
            kwargs["active_tags"] = active_tags
        super().__init__(kwargs)



"""
Update a single service object returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.pager_duty_integration_api import PagerDutyIntegrationApi
from datadog_api_client.v1.model.pager_duty_service_key import PagerDutyServiceKey

body = PagerDutyServiceKey(
    service_key="",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = PagerDutyIntegrationApi(api_client)
    api_instance.update_pager_duty_integration_service(service_name="service_name", body=body)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetSummaryType(ModelSimple):
    """
    Which summary type should be used.

    :param value: Must be one of ["monitors", "groups", "combined"].
    :type value: str
    """

    allowed_values = {
        "monitors",
        "groups",
        "combined",
    }
    MONITORS: ClassVar["WidgetSummaryType"]
    GROUPS: ClassVar["WidgetSummaryType"]
    COMBINED: ClassVar["WidgetSummaryType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetSummaryType.MONITORS = WidgetSummaryType("monitors")
WidgetSummaryType.GROUPS = WidgetSummaryType("groups")
WidgetSummaryType.COMBINED = WidgetSummaryType("combined")
